*
*
* COUNTRY AND YEAR-SPECIFIC DEATH ESTIMATES FOR HIB AND PNEUMOCOCCUS
* Author: Brian Wahl
* Contact: bwahl@jhu.edu; bpwahl@gmail.com

* This file contains all of the analyses for the global estimates of Hib, 
* and pneumococcus deaths among children less than five years of age. Several 
* input files are needed. 
*
* Folders and folder contents that need to be in the working directory are: 
*
*	1. Input Files
*		1a. countries.csv (list of countries and UN/WHO regions)
*		1b. RatesDeaths_AllIndicators.xlsx (IGME child mortality estimates; 
*			http://www.childmortality.org)
*		1c. WPP2015_POP_F15_1_ANNUAL_POPULATION_BY_AGE_BOTH_SEXES.xls 
*			(Under 5 population estimates; http://esa.un.org/unpd/wpp/DVD/)
* 		1d. coverage_estimates_series.xls (vaccine covearge estimates; 
*			http://www.who.int/immunization/monitoring_surveillance/routine/coverage/en/index4.html)
*		1e. pcv_coverage_2015.csv (compiled from various sources)
*		1f. mening_vaccine.xlsx (compliled by Adena Greenbaum from various 
*			sources)	
*		1g. HIV2014Estimates_HIV_20Oct2015.xlsx (2016 estimates, contact: mahym@unaids.org to request access)
*		1i. Pneumonia_careseeking_treatment_indicators_June 2015_UNICEF_1582c25 
*			(MICS estimates for access to care; http://data.unicef.org/Pneumonia_careseeking_treatment_indicators_June%202015_UNICEF_1582c25.xlsx) 
*		1h. undo_posthoc_global all.dta	(Li Liu, et al.)
* 		1i. global 2015_national men epi.dta (from Li Liu, et al.)
*
*	2. Pneumonia
*		2a. pneumonia_trials.csv
*
*	3. Meningitis Proportion
*		3a. meningitis_cfr.csv
*		3b. meningitis_proportion.csv
*
*	4. NPNM
*		5a. npnm.csv
*		5b. npnm_cfr.csv
*		5c. npnm_cfr_ma.csv
*
* TABLE OF CONTENTS
*
*	A. Prepare country inputs 
*	B. Estimate proportion of pneumonia deaths/cases
*	C. Estimate proportion of meningitis deaths
*	D. Estimate of NPNM ratio compared to meningitis cases
*	E. Estimate pathogen-specific meningitis incidence and CFR
* 	F. Develop VEC estimates
*	G. Pneumonia mortality estimates (HIV- and HIV+) and uncertainty ranges
*	H. Pneumonia morbidity estimates (HIV- and HIV+) and uncertainty ranges
*	I. Meningitis mortality estimates (HIV- and HIV+) and uncertainty ranges (Proportion)
* 	J. Meningitis morbidity estimates (HIV- and HIV+) and uncertainty ranges (Proportion)
*	K. Meningitis morbidity estimates (HIV- and HIV+) and uncertainty ranges (Incidence)
* 	L. Meningitis mortality estimates (HIV- and HIV+) and uncertainty ranges (Incidence)
*	M. NPNM morbidity estimates (HIV- and HIV+) and uncertainty ranges
*	N. NPNM mortality estimates (HIV- and HIV+) and uncertainty ranges
*	O. Calculate rates
*
********************************************************************************

*	A. Prepare country inputs 
do "prepare_country_inputs.do"


********************************************************************************

*	B. Estimate proportion of pneumonia deaths/cases
cd "./2. Pneumonia"

* Getting set up
import delimited "pneumonia_trials.csv", encoding(ISO-8859-1)clear
keep disease trial impact clinical_est clinical_se severe_est severe_se ///
cxr_est cxr_se meningitis_est meningitis_se vt_est vt_se
destring clinical_est clinical_se severe_est severe_se cxr_est ///
cxr_se meningitis_est meningitis_se vt_est vt_se, force replace
drop if impact == 1

* Adjustment for vaccine efficacy against meningitis (proxy for invasive
* disease) for Hib vaccine and IPD for PCV.
foreach v in clinical severe cxr {
	replace `v'_se = sqrt((1/meningitis_est)^2 * `v'_se^2 + ///
	(`v'_est/meningitis_est)^2 * meningitis_se^2 - 1 * (1/meningitis_est) * ///
	`v'_se * (`v'_est / meningitis_est) * meningitis_se)
	replace `v'_est = `v'_est / meningitis_est
}
*

* Adjustment for ST coverage (for pneumococcus only).
foreach v in clinical severe cxr {
	replace `v'_se = sqrt((1/vt_est)^2 * `v'_se^2 + (`v'_est/vt_est)^2 * ///
	vt_se^2 - 1 * (1 / vt_est) * `v'_se * (`v'_est / vt_est) * vt_se) if ///
	disease == "spn"
	replace `v'_est = `v'_est / vt_est if disease == "spn" 
}
*

* Meta-analysis for Hib vaccine
foreach v in clinical severe cxr{
	gen `v'_est_lg = log(1 - `v'_est)
}
*
local newobs = _N + 2 
set obs `newobs'
local newobsm1 = `newobs' - 1
replace disease = "hib" in `newobsm1'
replace disease = "spn" in `newobs'
replace trial = "all" if trial == "" 

foreach v in clinical severe cxr {
	quietly metan `v'_est_lg `v'_se if disease == "hib" & trial != "all", ///
	random nograph
	replace `v'_est_lg = r(ES) in `newobsm1'
	replace `v'_se = r(seES) in `newobsm1'	
	replace `v'_est = (1-exp(`v'_est_lg)) in `newobsm1'
}
*

* With Hib MA done, adjust for Hib vaccine use in PCV studies
foreach v in clinical severe cxr {
	local hib_est = `v'_est in `newobsm1'
	local hib_se = `v'_se in `newobsm1'
	replace `v'_se = sqrt((1 - `hib_est')^2 * (`v'_se)^2 + (`v'_est)^2 * ///
	(`hib_se')^2) if disease == "spn" & trial != "all"
	replace `v'_est = `v'_est * (1 - `hib_est') if disease == "spn" & ///
	trial != "all" 
}
*

* MA for Spn
foreach v in clinical severe cxr {
	replace `v'_est_lg = log(1 - `v'_est) if disease == "spn" & trial != "all" 
	quietly metan `v'_est_lg `v'_se if disease == "spn" & trial != "all", ///
	random nograph
	replace `v'_est_lg = r(ES) in `newobs' 
	replace `v'_est = (1-exp(`v'_est_lg)) in `newobs'
	replace `v'_se = r(seES) in `newobs'
}
*
export delimited disease trial clinical_est clinical_se severe_est severe_se ///
cxr_est cxr_se using "pneumonia_trials_adjusted_ma", replace

* Leave one study out analysis
count 
local count = r(N)
local studies = `count' - 2 
count if disease == "hib" & trial != "all" 
local hibcount = r(N) 
count if disease == "spn" & trial != "all" 
local spcount = r(N) 
local firstsp = `hibcount' + 1 

local hibstartadded = `count' + 1
local hibendadded = `hibstartadded' + `hibcount' - 1
local spstartadded = `hibendadded' + 1 
local newobsl1o = _N + (_N - 2)  
set obs `newobsl1o'  

local added = `newobsl1o' - `count' + 2 

replace disease = "hib" in `hibstartadded'/`hibendadded'
replace disease = "spn" in `spstartadded'/`newobsl1o' 


forval i = `hibstartadded'/`newobsl1o' {
	replace trial = "No "+trial[`i'-`added'] in `i'
}
*

forval i = 1/`hibcount' {
	foreach v in clinical severe cxr {
		quietly metaan `v'_est_lg `v'_se if disease == "hib" & ///
		trial != "all" & _n !=`i' & _n < `studies', dl
		local n = `i' + `added'
		replace `v'_est_lg = r(eff) in `n'
		replace `v'_est = 1-exp(`v'_est_lg) in `n'
		replace `v'_se = sqrt(r(effvar)) in `n'
		}
}
*

forval i = `firstsp'/`studies'  {
	foreach v in clinical severe cxr {
		quietly metaan `v'_est_lg `v'_se if disease == "spn" ///
		& trial != "all" & _n !=`i' & _n < `studies' , dl
		local n = `i' + `added'
		replace `v'_est_lg = r(eff) in `n'
		replace `v'_est = (1-exp(r(eff))) in `n'
		replace `v'_se = sqrt(r(effvar)) in `n'
		}
}
*
export delimited disease trial clinical_est clinical_se severe_est severe_se ///
cxr_est cxr_se using "pneumonia_trials_jackknife" if _n > `count', replace

cd ".."


********************************************************************************

*	C. Estimate proportion of meningitis deaths
cd "./3. Meningitis"

* Start with meningitis CFR

* Getting set up
import delimited "meningitis_cfr.csv", clear
drop if duplicate == "yes"
drop if article_num == "7921" // Only one case. 

* Adjust by ratio of U1/U5 and U2/U5 CFR for studies with no U5 data
foreach age in "0_11" "0_23" "0_59" { 	
	replace  cfr_`age' =  cfr_`age'/100 // Convert CFR to proportion.
	gen cfr_`age'_se = sqrt(((cfr_`age')*(1-cfr_`age'))/case_`age') if ///
	case_`age' != . & cfr_`age' != .
	replace cfr_`age'_se = 0.05 if cfr_`age'_se == 0
}
*
foreach age in "0_11" "0_23"  {
	gen cfr_ratio_`age' = logit(cfr_`age'/cfr_0_59) if cfr_`age' != . & ///
	cfr_0_59 != .
	gen cfr_ratio_`age'_se = sqrt((1/cfr_0_59)^2 * (cfr_`age') * ///
	(1 - cfr_`age')/case_`age' + (1/(cfr_0_59))^4 * (cfr_`age')^2 * cfr_0_59 * ///
	(1-cfr_0_59)/case_0_59) if cfr_`age' != . & cfr_0_59 != .	
}
*
foreach pathogen in hib spn nm {
	quietly capture metan cfr_ratio_0_11 cfr_ratio_0_11_se if ///
	pathogen == "`pathogen'", random nograph
	local adj_`pathogen'_0_11 invlogit(r(ES))
	quietly capture metan cfr_ratio_0_23 cfr_ratio_0_23_se if ///
	pathogen == "`pathogen'", random nograph
	local adj_`pathogen'_0_23 invlogit(r(ES))
	replace cfr_0_59 = cfr_0_11/`adj_`pathogen'_0_11' if cfr_0_59 == . & ///
	cfr_ratio_0_23 == . & cfr_0_11 != .
	replace cfr_0_59 = cfr_0_23/`adj_`pathogen'_0_23' if cfr_0_59 == . & ///
	cfr_0_23 != . 
	replace cfr_0_59_se = 0.05 if cfr_0_59_se == . & cfr_0_59 != .
}
*

* Transformations for MA
foreach age in "0_11" "0_23" "0_59" { 	
	gen cfr_`age'_asin = asin(sqrt(cfr_`age')) // Angular transformation. 
	replace cfr_`age'_se = sqrt(1/(4 * case_`age')) // Angular transformation SE
}
*

* MA results by pathogen and mortality stratum for point estimates and 95% CI
quietly {
	capture log close table
	capture log using meningitis_cfr_ma.csv, text name(table) replace
	noisily disp "pathogen,mortality_stratum,cfr,cfr_se,cfr_lb,cfr_ub,i2"
		foreach pathogen in hib spn nm {
			local stratum `" "1.Very Low" "2.Medium" "3.High" "4.Very High" "'
			foreach stratum in `stratum' {
				capture metan cfr_0_59_asin cfr_0_59_se if ///
				mortality_stratum_recode == "`stratum'" & pathogen == ///
				"`pathogen'", random nograph
				noisily disp "`pathogen',`stratum'," %5.4f sin(r(ES))^2 ///
				","%5.4f r(seES) "," %5.4f sin(r(ci_low))^2 "," ///
				%5.4f sin(r(ci_upp))^2 "," %4.3f r(i_sq)/100
			}
		}
	log close table
}
*

* Leave one study out jack knife analysis 
bysort mortality_stratum_recode pathogen: gen count = _n
quietly {
	capture log close table
	capture log using meningitis_cfr_jackknife.csv, text name(table) replace
	noisily disp "pathogen,study,mortality_stratum,cfr,cfr_se,cfr_lb,cfr_ub,i2"
		foreach pathogen in hib spn nm {
			local stratum `" "1.Very Low" "2.Medium" "3.High" "4.Very High" "'
			foreach stratum in `stratum' {
				count if pathogen == "`pathogen'" & ///
				mortality_stratum_recode == "`stratum'"
				local count = r(N)
				forval i = 1/`count' {
					capture metan cfr_0_59_asin cfr_0_59_se if ///
					mortality_stratum_recode == "`stratum'" & pathogen == ///
					"`pathogen'" &  count !=`i', random nograph
					noisily disp "`pathogen'" "," "No "article_num[`i'] "," ///
					"`stratum'," %5.4f sin(r(ES))^2 ","%5.4f r(seES) "," ///
					%5.4f sin(r(ci_low))^2 "," %5.4f sin(r(ci_upp))^2 "," %4.3f r(i_sq)/100
				}
			}
		}
	log close table
}
drop count

* Proportion of cases due to each pathogen 

* Getting set up
import delimited "meningitis_proportion.csv", clear
drop if duplicate == "yes"
drop if hib_vx == "yes"
drop if exclude == "yes"
drop if hib_cases_0_59 == . | spn_cases_0_59 == . | nm_cases_0_59 == .
drop if total_cases_0_59 == .

* First get proportion of cases that are due to the three pathogens and identify 
* which studies will be included in this analysis. Because some studies only 
* identified the three pathogens of interest and others used more sensitive 
* tests for the three pathogens of interest, we limited this analysis to those 
* studies assumed to have equal sensitivity for all pathogens.  
gen sum_three = hib_cases_0_59 + spn_cases_0_59 + nm_cases_0_59
gen other = 0 // Specifies which studies are included in the analysis. 
replace other = 1 if sum_three != total_cases_0_59 
replace other = 0 if binax == 1 | latex == 1 | pcr == 1 // Latex and PCR coded 
* as 1 are only sensitive to the three pathogens of interest. 

* Transforms the outcome and creates standard errors. 
gen other_prop = (total_cases_0_59 - sum_three)/total_cases_0_59
gen other_prop_asin = asin(sqrt(other_prop))
gen other_prop_se = sqrt(1/(4 * total_cases_0_59))

* Create tables with the results of the point estimates and 95% CI for "other"
sort other_prop_asin
quietly { 
	capture log close table
	capture log using meningitis_proportion_other_ma.csv, text name(table) replace
	noisily disp "proportion,proportion_se, proportion_lb,proportion_ub,number_of_studies,i2"
	capture metan other_prop_asin other_prop_se if other== 1, ///
	random nograph
	noisily disp %5.4f sin(r(ES))^2 "," %5.4f r(seES) "," ///
	%5.4f sin(r(ci_low))^2 "," %5.4f sin(r(ci_upp))^2 "," r(df)+1 "," %4.3f r(i_sq)/100
log close table
}
*	

* Leave one study out jack knife analysis for "other"
bysort other: gen counter = _n
quietly {
	capture log close table
	capture log using meningitis_proportion_other_jackknife.csv, ///
	text name(table) replace
	noisily disp "study,proportion,proportion_se"
	count if other== 1
	local count = r(N)
	forval i = 1/`count' {
		capture metan other_prop_asin other_prop_se if other==1 & ///
		counter != `i', random nograph
		noisily disp "No "article_num[`i'] "," %5.4f sin(r(ES))^2 "," ///
		%5.4f r(seES)
	}
log close table
}
drop counter

* First need to adjust proportions by HIV prevalence

* Prepare historical data
cd ".."
cd "./1. Input Files"
preserve
import delimited "countryhivprevalence.csv", varnames(1) clear
drop code v4
rename country whoname
reshape long v, i(whoname) j(year)
replace year = year + 1976
rename v hiv_prev
replace whoname = "Cote d'Ivoire" if whoname == "Cote d´Ivoire"
save "historical_hiv.dta", replace
restore

* Set up year for merging
generate study_date = date(study_midpoint, "MDY", 2010)
format study_date %td
gen year = year(study_date)
merge m:1 whoname year using "historical_hiv.dta"
rename hiv_prev hiv_prev_hist
drop if _merge == 2
drop _merge
merge m:1 whoname year using "hiv.dta"
drop if _merge == 2
drop _merge
cd ".."
cd "./3. Meningitis"
gen hiv = hiv_prev
replace hiv = hiv_prev_hist if hiv == .
replace hiv = 0 if hiv == .

* Adjust backward for HIV prevalence during Study
gen spn_cases_hiv_0_59 = spn_cases_0_59/($spn_hiv_rr * hiv + (1 - hiv))
gen hib_cases_hiv_0_59 = hib_cases_0_59/($hib_hiv_rr * hiv + (1 - hiv))
gen nm_cases_hiv_0_59 = nm_cases_0_59/($nm_hiv_rr * hiv + (1 - hiv))
gen sum_three_hiv = spn_cases_hiv_0_59 + hib_cases_hiv_0_59 + nm_cases_hiv_0_59

* Relative proportion of case of each pathogen by region

* First, start by transforming each variable. 
foreach pathogen in hib spn nm {
	gen prop_`pathogen' = `pathogen'_cases_hiv_0_59/sum_three_hiv
	gen prop_`pathogen'_asin = asin(sqrt(prop_`pathogen'))
	gen prop_`pathogen'_se = sqrt(1/(4*sum_three))
}
*

* MA for relative proportion point estimates and 95% CI
quietly { 
	capture log close table
	capture log using meningitis_proportion_ma.csv, text name(table) replace
	noisily disp "pathogen,region,proportion,proportion_se,proportion_lb,proportion_ub,number,i2"
	foreach pathogen in hib spn nm {
		local region `" "Africa" "Asia" "Europe" "Latin America and the Carribean" "Northern America" "Oceania" "'
		foreach region in `region' {
			capture metan prop_`pathogen'_asin prop_`pathogen'_se if ///
			region == "`region'", random nograph
			noisily disp "`pathogen',`region',"  %5.4f sin(r(ES))^2 "," ///
			%5.4f r(seES) "," %5.4f sin(r(ci_low))^2 "," ///
			%5.4f sin(r(ci_upp))^2 "," r(df)+1 "," %4.3f r(i_sq)/100
			}
		}
log close table
}
*

* Leave one study out jack knife analysis for relative proportion
bysort region: gen counter = _n 
quietly {
	capture log close table
	capture log using meningitis_proportion_jackknife.csv, text name(table) replace
	noisily disp "pathogen,region,study,proportion,proportion_se,proportion_lb,proportion_ub,i2"
		foreach pathogen in hib spn nm {
			local region `" "Africa" "Asia" "Europe" "Latin America and the Carribean" "Northern America" "Oceania" "'
			foreach region in `region' {
				count if region == "`region'"
				local count = r(N)
				forval i = 1/`count' {
					capture metan prop_`pathogen'_asin prop_`pathogen'_se if ///
					region == "`region'" & counter != `i', random nograph
					noisily disp "`pathogen',`region',No " article_num[`i'] ///
					"," %5.4f sin(r(ES))^2 "," %5.4f r(seES) "," %5.4f sin(r(ci_low))^2 "," ///
					%5.4f sin(r(ci_upp))^2 "," %4.3f r(i_sq)/100
				}
			}
		}
log close table
}
drop counter

cd ".."

********************************************************************************

*	D. Estimate of NPNM ratio compared to meningitis cases
cd "./4. NPNM"

* Getting set up
import delimited "npnm.csv", encoding(ISO-8859-1)clear

* Proportion and SE for each age group
foreach age in "0_11" "0_23" "0_59" {
	replace all_`age' = pneumonia_`age' + npnm_`age' + meningitis_`age' ///
	if all_`age' == . // Get denominator if one is not provided.
	gen ratio_`age' = npnm_`age'/meningitis_`age' // Get ratio. 
	gen ratio_`age'_se = sqrt((1/(meningitis_`age'/all_`age'))^2 * ///
	(npnm_`age'/all_`age') * (1-npnm_`age'/all_`age')/all_`age' + ///
	(1/(meningitis_`age'/all_`age'))^4 * (npnm_`age'/all_`age')^2 * ///
	meningitis_`age'/all_`age' * (1-meningitis_`age'/all_`age')/all_`age') 
	replace ratio_`age'_se = 0.05 if ratio_`age'_se == . & ratio_`age' != . 
}
*

* Adjust by ratio of U1/U5 and U2/U5 cases for studies with no U5 data
foreach age in "0_11" "0_23" {
	gen ratio_`age'_59 = logit(ratio_`age'/ratio_0_59) if ratio_`age' != . & ratio_0_59 != .
	gen ratio_`age'_59_se = ((1/ratio_0_59)^2 * ratio_`age'_se^2 + ///
	(1/ratio_0_59)^4 * ratio_`age'^2 * ratio_0_59_se^2) if ratio_`age' != . & ///
	ratio_0_59 != .
}
*
foreach path in hib spn {
	quietly metan ratio_0_11_59 ratio_0_11_59_se if pathogen == "`path'", ///
	random nograph
	local u1_adj_`path' invlogit(r(ES))
	local u1_adj_`path'_se r(seES)
	quietly metan ratio_0_23_59 ratio_0_23_59_se if pathogen == "`path'", ///
	random nograph
	local u2_adj_`path' invlogit(r(ES))
	local u2_adj_`path'_se r(seES)
	
	replace ratio_0_59 = ratio_0_11/`u1_adj_`path'' if ratio_0_59 == . & ///
	ratio_0_23 == . & ratio_0_11 != . & pathogen == "`path'"
	replace ratio_0_59_se = sqrt((1/`u1_adj_`path'')^2 * `u1_adj_`path'_se'^2 ///
	+ (1/`u1_adj_`path'')^4 * `u1_adj_`path''^2 * `u1_adj_`path'_se'^2) if ///
	ratio_0_59_se == . & ratio_0_23 == . & ratio_0_11 != . & pathogen == "`path'"
	
	replace ratio_0_59 = ratio_0_23/`u2_adj_`path'' if ratio_0_59 == . & ///
	ratio_0_23 != . & pathogen == "`path'"
	replace ratio_0_59_se = sqrt((1/`u2_adj_`path'')^2 * `u2_adj_`path'_se'^2 ///
	+ (1/`u1_adj_`path'')^4 * `u1_adj_`path''^2 * `u1_adj_`path'_se'^2) if ///
	ratio_0_59_se == . & ratio_0_23 != . & pathogen == "`path'"
}
*
* Multiplier for Hib/Spn NPNM severe
gen ratio_0_59_log = log(ratio_0_59)
quietly { 
	capture log close table
	capture log using npnm_ma.csv, text name(table) replace
	noisily disp "pathogen,severity,mortality_strata,inc_multiplier,inc_multiplier_se,studies"
	foreach path in hib spn {
		capture metan ratio_0_59_log ratio_0_59_se if pathogen == "`path'" ///
		& (mortality_stratum == "1.Very Low" | mortality_stratum == "2.Medium"), random nograph
		noisily disp "`path',severe,1.Very Low," %5.4f exp(r(ES)) "," ///
		%5.4f r(seES) "," r(df)+1 
		noisily disp "`path',severe,2.Medium," %5.4f exp(r(ES)) "," ///
		%5.4f r(seES) "," r(df)+1 
		capture metan ratio_0_59_log ratio_0_59_se if pathogen == "`path'" ///
		& (mortality_stratum == "3.High" | mortality_stratum == "4.Very High"), random nograph
		noisily disp "`path',severe,3.High," %5.4f exp(r(ES)) "," ///
		%5.4f r(seES) "," r(df)+1 
		noisily disp "`path',severe,4.Very High," %5.4f exp(r(ES)) "," ///
		%5.4f r(seES) "," r(df)+1 
	}
log close table
}
*		
* Multiplier for Spn NPNM non-severe
import delimited "npnm.csv", encoding(ISO-8859-1)clear
drop if severe_0_11 == 1 & severe_0_23 == 1 & severe_0_59 == 1

foreach age in "0_11" "0_23" "0_59" {
	gen nonsevere_`age' = 1 - severe_`age'
	foreach syn in pneumonia npnm meningitis all {
		replace `syn'_`age' = `syn'_`age' * nonsevere_`age'
	}
}
*
foreach age in "0_11" "0_23" "0_59" {
	replace all_`age' = pneumonia_`age' + npnm_`age' + meningitis_`age' ///
	if all_`age' == . // Get denominator if one is not provided.
	gen ratio_`age' = npnm_`age'/meningitis_`age' // Get ratio. 
	gen ratio_`age'_se = sqrt((1/(meningitis_`age'/all_`age'))^2 * ///
	(npnm_`age'/all_`age') * (1-npnm_`age'/all_`age')/all_`age' + ///
	(1/(meningitis_`age'/all_`age'))^4 * (npnm_`age'/all_`age')^2 * ///
	meningitis_`age'/all_`age' * (1-meningitis_`age'/all_`age')/all_`age') // SE.
	replace ratio_`age'_se = 0.05 if ratio_`age'_se == . & ratio_`age' != . // Replace SE if 0. 
	
}
*
foreach age in "_0_11" "_0_23" {
	gen ratio`age'_59 = ratio`age'/ratio_0_59 if ratio`age' != . & ratio_0_59 != .
	gen ratio`age'_59_se = ((1/ratio_0_59)^2 * ratio`age'_se^2 + ///
	(1/ratio_0_59)^4 * ratio`age'^2 * ratio_0_59_se^2) if ratio`age' != . & ///
	ratio_0_59 != .
	replace ratio`age'_59 = logit(ratio`age'_59) if ratio`age'_59 != . 
}
*
foreach path in hib spn {
	quietly metan ratio_0_11_59 ratio_0_11_59_se if pathogen == "`path'", ///
	random nograph
	local u1_adj_`path' invlogit(r(ES))
	local u1_adj_`path'_se r(seES)
	quietly metan ratio_0_23_59 ratio_0_23_59_se if pathogen == "`path'", ///
	random nograph
	local u2_adj_`path' invlogit(r(ES))
	local u2_adj_`path'_se r(seES)
	replace ratio_0_59 = ratio_0_11/`u1_adj_`path'' if ratio_0_59 == . & ///
	ratio_0_23 == . & ratio_0_11 != . & pathogen == "`path'"
	
	replace ratio_0_59_se = sqrt((1/`u1_adj_`path'')^2 * `u1_adj_`path'_se'^2 ///
	+ (1/`u1_adj_`path'')^4 * `u1_adj_`path''^2 * `u1_adj_`path'_se'^2) if ///
	ratio_0_59_se == . & ratio_0_23 == . & ratio_0_11 != . & pathogen == "`path'"
	
	replace ratio_0_59 = ratio_0_23/`u2_adj_`path'' if ratio_0_59 == . & ///
	ratio_0_23 != . & pathogen == "`path'"
	replace ratio_0_59_se = sqrt((1/`u2_adj_`path'')^2 * `u2_adj_`path'_se'^2 ///
	+ (1/`u1_adj_`path'')^4 * `u1_adj_`path''^2 * `u1_adj_`path'_se'^2) if ///
	ratio_0_59_se == . & ratio_0_23 != . & pathogen == "`path'"
}
*
gen ratio_0_59_log = ln(ratio_0_59)
quietly { 
	capture log close table
	capture log using npnm_nonsevere_ma.csv, text name(table) replace
	noisily disp "pathogen,severity,mortality_strata,inc_multiplier,inc_multiplier_se,studies"
	capture metan ratio_0_59_log ratio_0_59_se, random nograph
	noisily disp "spn,nonsevere,1.Very Low/2.Medium/3.High/4.Very High," %5.4f exp(r(ES)) "," %5.4f r(seES) "," r(df)+1 
	log close table
}
*

cd ".."


********************************************************************************

* 	F. Develop VEC estimates

* Getting set up
use "countries_time_series.dta", clear
global hib_ve = 0.95 // Wolfson
global pcv_ve = 0.80 // Lucero
global men_a_ve = 0.90 // 
global men_c_ve = 0.80 //

* Direct effects (Hib)
gen hib3_vec = $hib_ve * hib3
gen hib3_vec_adj = $hib_ve * hib3_adj

* Direct effects (PCV)
gen pcv_vec = $pcv_ve * ((pcv7 * pcv7_st) + (pcv10 * pcv10_st) + (pcv13 * pcv13_st))
gen pcv_vec_adj = $pcv_ve * ((pcv7_adj * pcv7_st) + (pcv10_adj * pcv10_st) + (pcv13_adj * pcv13_st))

* Direct effects (Men)
gen men_vec = 0
gen men_vec_epi = 0
replace men_vec = $men_a_ve * men_vx * a_men_sg if men_vx_sg_adj == "a"
replace men_vec = $men_c_ve * men_vx * c_men_sg if men_vx_sg_adj == "c"
replace men_vec_epi = $men_a_ve * men_vx * a_men_sg_epi if men_vx_sg_adj == "a"
replace men_vec_epi = $men_c_ve * men_vx * c_men_sg_epi if men_vx_sg_adj == "c"

* Indirect effects
* Hib
gen hib3_vec_ind = 0
replace hib3_vec_ind = (hib3 * 2.428) - 0.1379 if hib3 < 0.4 & hib3 != 0 
replace hib3_vec_ind = (hib3 * 2.428) - ((hib3-0.40) * 2.257) - 0.1379 if hib3 >= 0.4
replace hib3_vec_ind = hib3 * $hib_ve if hib3 > 0.98 
replace hib3_vec_ind = 0.99 if years_after_hib > 5 & hib3 > 0.65
replace hib3_vec_ind = hib3 * $hib_ve if hib3 < 0.10 & hib3 != 0

gen hib3_vec_ind_adj = 0
replace hib3_vec_ind_adj = (hib3_adj * 2.428) - 0.1379 if hib3_adj < 0.4 & hib3_adj != 0 
replace hib3_vec_ind_adj = (hib3_adj * 2.428) - ((hib3_adj - 0.40) * 2.257) - 0.1379 if hib3_adj >= 0.4
replace hib3_vec_ind_adj = hib3_adj * $hib_ve if hib3_adj > 0.98
replace hib3_vec_ind_adj = 0.99 if years_after_hib > 5 & hib3_adj > 0.65
replace hib3_vec_ind_adj = hib3_adj * $hib_ve if hib3_adj < 0.10 & hib3_adj != 0

bysort iso3 year: replace hib3_vec_ind = 0.99 if hib3_vec_ind[_n-1] == 0.99 & hib3_vec_ind[_n+1] == 0.99
bysort iso3 year: replace hib3_vec_ind_adj = 0.99 if hib3_vec_ind_adj[_n-1] == 0.99 & hib3_vec_ind_adj[_n+1] == 0.99

* PCV 
gen pcv_vec_ind = pcv_vec
replace pcv_vec_ind = 0.95 * pcv7_st if years_after_pcv >= 5 & pcv7 > 0.65
replace pcv_vec_ind = 0.95 * pcv10_st if years_after_pcv >= 5 & pcv10 > 0.65
replace pcv_vec_ind = 0.95 * pcv13_st if years_after_pcv >= 5 & pcv13 > 0.65

gen pcv_vec_ind_adj = pcv_vec_adj
replace pcv_vec_ind_adj = 0.95 * pcv7_st if years_after_pcv >= 5 & pcv7_adj > 0.65
replace pcv_vec_ind_adj = 0.95 * pcv10_st if years_after_pcv >= 5 & pcv10_adj > 0.65
replace pcv_vec_ind_adj = 0.95 * pcv13_st if years_after_pcv >= 5 & pcv13_adj > 0.65

* Account for ST replacement with PCV7
replace pcv_vec_ind = ((1 - ((pcv7_st * vt_rr) + (nvt_rr * (1 - pcv7_st)))) * pcv7) if pcv10 == 0 & pcv13 == 0 & pcv7 != 0
replace pcv_vec_ind = ((1 - ((pcv7_st * vt_rr) + (nvt_rr * (1 - pcv7_st)))) * pcv7) + ($pcv_ve * pcv10 * pcv10_st) if pcv7 > 0 & pcv10 > 0 
replace pcv_vec_ind = ((1 - ((pcv7_st * vt_rr) + (nvt_rr * (1 - pcv7_st)))) * pcv7) + ($pcv_ve * pcv13 * pcv13_st) if pcv7 > 0 & pcv13 > 0

replace pcv_vec_ind_adj = ((1 - ((pcv7_st * vt_rr) + (nvt_rr * (1 - pcv7_st)))) * pcv7_adj) if pcv10_adj == 0 & pcv13_adj == 0 & pcv7_adj != 0
replace pcv_vec_ind_adj = ((1 - ((pcv7_st * vt_rr) + (nvt_rr * (1 - pcv7_st)))) * pcv7_adj) + ($pcv_ve * pcv10_adj * pcv10_st) if pcv7_adj > 0 & pcv10_adj > 0 
replace pcv_vec_ind_adj = ((1 - ((pcv7_st * vt_rr) + (nvt_rr * (1 - pcv7_st)))) * pcv7_adj) + ($pcv_ve * pcv13_adj * pcv13_st) if pcv7_adj > 0 & pcv13_adj > 0

* Birth cohort adjustment for PCV (direct)
gen pcv_vec_2_11 = .
gen pcv_vec_12_23 = .
gen pcv_vec_24_35 = .
gen pcv_vec_36_47 = .
gen pcv_vec_48_59 = .
replace pcv_vec_2_11 = pcv_vec
sort whoname year
by whoname: replace pcv_vec_12_23 = pcv_vec[_n - 1]
by whoname: replace pcv_vec_24_35 = pcv_vec[_n - 2]
by whoname: replace pcv_vec_36_47 = pcv_vec[_n - 3]
by whoname: replace pcv_vec_48_59 = pcv_vec[_n - 4]
replace pcv_vec_12_23 = 0 if pcv_vec_12_23 == .
replace pcv_vec_24_35 = 0 if pcv_vec_24_35 == .
replace pcv_vec_36_47 = 0 if pcv_vec_36_47 == .
replace pcv_vec_48_59 = 0 if pcv_vec_48_59 == .

* Birth cohort adjustment for PCV (indirect)
gen pcv_vec_ind_2_11 = .
gen pcv_vec_ind_12_23 = .
gen pcv_vec_ind_24_35 = .
gen pcv_vec_ind_36_47 = .
gen pcv_vec_ind_48_59 = .
replace pcv_vec_ind_2_11 = pcv_vec_ind
sort whoname year
by whoname: replace pcv_vec_ind_12_23 = pcv_vec_ind[_n - 1]
by whoname: replace pcv_vec_ind_24_35 = pcv_vec_ind[_n - 2]
by whoname: replace pcv_vec_ind_36_47 = pcv_vec_ind[_n - 3]
by whoname: replace pcv_vec_ind_48_59 = pcv_vec_ind[_n - 4]
replace pcv_vec_ind_12_23 = 0 if pcv_vec_ind_12_23 == .
replace pcv_vec_ind_24_35 = 0 if pcv_vec_ind_24_35 == .
replace pcv_vec_ind_36_47 = 0 if pcv_vec_ind_36_47 == .
replace pcv_vec_ind_48_59 = 0 if pcv_vec_ind_48_59 == .

********************************************************************************

*	G. Pneumonia mortality estimates (HIV- and HIV+) and uncertainty ranges

* Import results of meta-analysis
capture cd "./2. Pneumonia"
preserve
import delimited "pneumonia_trials_adjusted_ma.csv", clear
foreach pathogen in hib spn {
	foreach outcome in clinical severe cxr {
		quietly sum `outcome'_est if disease == "`pathogen'" & trial == "all"
		local `outcome'_`pathogen' = r(mean)
	}
}
restore 
foreach pathogen in hib spn {
	foreach outcome in clinical severe cxr {
	gen `outcome'_`pathogen' = ``outcome'_`pathogen''
	}
}
cd ".."

* Undo vaccine use for pneumonia in VR (i.e., non-post-hoc adjustment) countries
gen pn_pneumonia_adj = pn_pneumonia
replace pn_pneumonia_adj = pn_pneumonia/((1 - (hib3_vec_ind_adj * cxr_hib)) * ( ///
((1 - pcv_vec_ind_2_11 * cxr_spn) * ipd_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23 * cxr_spn) * ipd_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35 * cxr_spn) * ipd_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47 * cxr_spn) * ipd_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59 * cxr_spn) * ipd_deaths_48_59))) ///
if meth == "good vr" | meth == "other" | meth == "vrmcm" 

* We assume all Hib deaths occur among children less than two years of age. 
* Since we don't have age stratified deaths for Hib, we first need to estimate the 
* number of pneumonia deaths. 
gen deaths_1_11 = infant_deaths - neonatal_deaths
gen deaths_1_59 = u5_deaths - neonatal_deaths
gen deaths_12_59 = deaths_1_59 - deaths_1_11
gen deaths_1_23 = deaths_1_11 + (deaths_12_59/2)
gen ratio_1_23 =  deaths_1_59/deaths_1_23
replace ratio_1_23 = 1 if ratio_1_23 == . // Niue and Monaco only reported 1 U5
* death, all were among neonates.
gen pn_pneumonia_adj_1_23 = pn_pneumonia_adj/ratio_1_23 

* Get point estimates (Indirect Effects)
gen hib_pneumonia_deaths = pn_pneumonia_adj_1_23 * cxr_hib * (1 - hib3_vec_ind_adj)
gen spn_pneumonia_deaths = pn_pneumonia_adj * cxr_spn * ( ///
((1 - pcv_vec_ind_2_11) * ipd_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_deaths_48_59))

* Get point estimates (Direct Effects)
gen hib_pneumonia_deaths_d = pn_pneumonia_adj_1_23 * cxr_hib * (1 - hib3_vec_adj)
gen spn_pneumonia_deaths_d = pn_pneumonia_adj * cxr_spn * ( ///
((1 - pcv_vec_2_11) * ipd_deaths_1_11) + ///
((1 - pcv_vec_12_23) * ipd_deaths_12_23) + ///
((1 - pcv_vec_24_35) * ipd_deaths_24_35) + ///
((1 - pcv_vec_36_47) * ipd_deaths_36_47) + ///
((1 - pcv_vec_48_59) * ipd_deaths_48_59))

* No vaccine use
gen hib_pneumonia_deaths_n = pn_pneumonia_adj_1_23 * cxr_hib 
gen spn_pneumonia_deaths_n = pn_pneumonia_adj * cxr_spn 

* Get uncertainty ranges
cd "./2. Pneumonia"
preserve
import delimited "pneumonia_trials_jackknife.csv", clear
foreach pathogen in hib spn {
	foreach outcome in clinical severe cxr {
		quietly sum `outcome'_est if disease == "`pathogen'" 
		local `outcome'_`pathogen'_lb = r(min)
		local `outcome'_`pathogen'_ub = r(max)
	}
} 
restore 
foreach pathogen in hib spn {
	foreach outcome in clinical severe cxr {
		foreach b in lb ub {
			gen `outcome'_`pathogen'_`b' = ``outcome'_`pathogen'_`b''
		}
	}
}
* Indirect Effects  
gen hib_pneumonia_deaths_lb = pn_pneumonia_adj_1_23 * cxr_hib_lb * (1 - hib3_vec_ind_adj)
gen hib_pneumonia_deaths_ub = pn_pneumonia_adj_1_23 * cxr_hib_ub * (1 - hib3_vec_ind_adj)
gen spn_pneumonia_deaths_lb = pn_pneumonia_adj * cxr_spn_lb * ( ///
((1 - pcv_vec_ind_2_11) * ipd_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_deaths_48_59))
gen spn_pneumonia_deaths_ub = pn_pneumonia_adj * cxr_spn_ub * ( ///
((1 - pcv_vec_ind_2_11) * ipd_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_deaths_48_59))

* Direct Effects  
gen hib_pneumonia_deaths_lb_d = pn_pneumonia_adj_1_23 * cxr_hib_lb * (1 - hib3_vec_adj)
gen hib_pneumonia_deaths_ub_d = pn_pneumonia_adj_1_23 * cxr_hib_ub * (1 - hib3_vec_adj)
gen spn_pneumonia_deaths_lb_d = pn_pneumonia_adj * cxr_spn_lb * ( ///
((1 - pcv_vec_2_11) * ipd_deaths_1_11) + ///
((1 - pcv_vec_12_23) * ipd_deaths_12_23) + ///
((1 - pcv_vec_24_35) * ipd_deaths_24_35) + ///
((1 - pcv_vec_36_47) * ipd_deaths_36_47) + ///
((1 - pcv_vec_48_59) * ipd_deaths_48_59))
gen spn_pneumonia_deaths_ub_d = pn_pneumonia_adj * cxr_spn_ub * ( ///
((1 - pcv_vec_2_11) * ipd_deaths_1_11) + ///
((1 - pcv_vec_12_23) * ipd_deaths_12_23) + ///
((1 - pcv_vec_24_35) * ipd_deaths_24_35) + ///
((1 - pcv_vec_36_47) * ipd_deaths_36_47) + ///
((1 - pcv_vec_48_59) * ipd_deaths_48_59))

* No vaccine use 
gen hib_pneumonia_deaths_lb_n = pn_pneumonia_adj_1_23 * cxr_hib_lb
gen hib_pneumonia_deaths_ub_n = pn_pneumonia_adj_1_23 * cxr_hib_ub 
gen spn_pneumonia_deaths_lb_n = pn_pneumonia_adj * cxr_spn_lb 
gen spn_pneumonia_deaths_ub_n = pn_pneumonia_adj * cxr_spn_ub 

* HIV
foreach effect in "" "_d" "_n" {
	gen hib_pneumonia_deaths_hiv`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_deaths`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_pneumonia_deaths_hiv`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_deaths`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen hib_pneumonia_deaths_hiv_lb`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_deaths_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen hib_pneumonia_deaths_hiv_ub`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_deaths_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_pneumonia_deaths_hiv_lb`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_deaths_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen spn_pneumonia_deaths_hiv_ub`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_deaths_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
}
*

* Total pathogen-specific pneumonia deaths (HIV- and HIV+)
foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" { // Indirect and Direct Effects
		gen `pathogen'_pneumonia_deaths_total`effect' = `pathogen'_pneumonia_deaths_hiv`effect' + `pathogen'_pneumonia_deaths`effect'
		gen `pathogen'_pneumonia_deaths_total_lb`effect' = `pathogen'_pneumonia_deaths_hiv_lb`effect' + `pathogen'_pneumonia_deaths_lb`effect'
		gen `pathogen'_pneumonia_deaths_total_ub`effect' = `pathogen'_pneumonia_deaths_hiv_ub`effect' + `pathogen'_pneumonia_deaths_ub`effect'
	}
}
*

********************************************************************************

*	H. Pneumonia morbidity estimates (HIV- and HIV+) and uncertainty ranges

foreach suf in "" "_lb" "_ub" {
	replace pna_incidence`suf' = pna_incidence`suf'/1000
	replace pna_incidence_hiv`suf' = pna_incidence_hiv`suf'/1000
	replace pna_incidence_sev`suf' = pna_incidence_sev`suf'/1000
	replace pna_incidence_hiv_sev`suf' = pna_incidence_hiv_sev`suf'/1000
}
*

* Include estimates for HIC
replace pna_incidence = 0.015 if (year == 2000 | year == 2015) & ///
(who_region_effective == "EUR A" | who_region_effective == "AMR A")  ///
& pna_incidence == .

replace pna_incidence = 0.025 if (year == 2000 | year == 2015) & ///
who_region_effective == "WPR A" & pna_incidence == .

replace pna_incidence = 0.03 if (year == 2000 | year == 2015) & ///
(who_region_effective == "EUR B1" | who_region_effective == "EUR B2" | ///
who_region_effective == "EMR B" | who_region_effective == "AMR B" | ///
who_region_effective == "SEAR B") & pna_incidence == .

replace pna_incidence = 0.06 if (year == 2000 | year == 2015) & ///
(who_region_effective == "EUR C") & pna_incidence == .

* Lower and upper bounds taken from the JOGH supplement from Rudan, et al. 
* columns AT and AU. 
replace pna_incidence_lb = pna_incidence * 0.8 if ///
(year == 2000 | year == 2015) & (who_region_effective == "EUR A" | ///
who_region_effective == "AMR A"  | who_region_effective == "WPR A" | ///
who_region_effective == "EUR B1" | who_region_effective == "EUR B2" | ///
who_region_effective == "EMR B" | who_region_effective == "AMR B" | ///
who_region_effective == "SEAR B" | who_region_effective == "EUR C") & ///
pna_incidence_lb == .

replace pna_incidence_ub = pna_incidence * 1.33 if ///
(year == 2000 | year == 2015) & (who_region_effective == "EUR A" | ///
who_region_effective == "AMR A"  | who_region_effective == "WPR A" | ///
who_region_effective == "EUR B1" | who_region_effective == "EUR B2" | ///
who_region_effective == "EMR B" | who_region_effective == "AMR B" | ///
who_region_effective == "SEAR B" | who_region_effective == "EUR C") & ///
pna_incidence_ub == .


* Assume South Sudan has same incidence as Sudan 
foreach hiv in "" "_hiv" {
	foreach sev in "" "_sev" {
		foreach b in "" "_lb" "_ub" {
			quietly sum pna_incidence`hiv'`sev'`b' if year == 2015 & whoname == "Sudan"
			replace pna_incidence`hiv'`sev'`b' = r(mean) if year == 2015 & whoname == "South Sudan" 
		}
	}
}
*

* Generate episodes and upper and lower bounds for countries that only have incidence
foreach hiv in "" "_hiv" {
	foreach b in "" "_lb" "_ub" {
		replace pna_episodes`hiv'`b' = pna_incidence`hiv'`b' * pop_1_59 if (year == 2000 | year == 2015) & ///
		pna_episodes`hiv'`b' == .
	}
}
*


* Generate severe episodes and upper and lower bounds for IHC
foreach hiv in "" "_hiv" {
	foreach b in "" "_lb" "_ub" {
		replace pna_episodes`hiv'_sev`b' = pna_episodes`hiv'`b' * 0.267 if (year == 2000 | year == 2015) & ///
		pna_episodes`hiv'_sev`b' == . & whoname != "South Sudan"
	}
}
* And now for South Sudan
foreach hiv in "" "_hiv" {
	foreach b in "" "_lb" "_ub" {
		replace pna_episodes`hiv'_sev`b' = pna_incidence`hiv'_sev`b' * pop_1_59 if (year == 2015) & ///
		pna_episodes`hiv'_sev`b' == . & whoname == "South Sudan"
	}
}
*

* Clinical Pneumonia

* Get point estimates (Indirect Effects)
gen hib_pneumonia_cases = pna_episodes * clinical_hib * (1 - hib3_vec_ind_adj)
gen spn_pneumonia_cases = pna_episodes * clinical_spn * ( ///
((1 - pcv_vec_ind_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_cases_48_59))

* Get point estimates (Direct Effects)
gen hib_pneumonia_cases_d = pna_episodes * clinical_hib * (1 - hib3_vec_adj)
gen spn_pneumonia_cases_d = pna_episodes * clinical_spn * ( ///
((1 - pcv_vec_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_48_59) * ipd_cases_48_59))

* No vaccine use
gen hib_pneumonia_cases_n = pna_episodes * clinical_hib 
gen spn_pneumonia_cases_n = pna_episodes * clinical_spn 

* Uncertainty (Indirect Effects) 
gen hib_pneumonia_cases_lb = pna_episodes * clinical_hib_lb * (1 - hib3_vec_ind_adj)
gen hib_pneumonia_cases_ub = pna_episodes * clinical_hib_ub * (1 - hib3_vec_ind_adj)
gen spn_pneumonia_cases_lb = pna_episodes * clinical_spn_lb * ( ///
((1 - pcv_vec_ind_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_cases_48_59))
gen spn_pneumonia_cases_ub = pna_episodes * clinical_spn_ub * ( ///
((1 - pcv_vec_ind_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_cases_48_59))

* Uncertainty (Direct Effects)
gen hib_pneumonia_cases_lb_d = pna_episodes * clinical_hib_lb * (1 - hib3_vec_adj)
gen hib_pneumonia_cases_ub_d = pna_episodes * clinical_hib_ub * (1 - hib3_vec_adj)
gen spn_pneumonia_cases_lb_d = pna_episodes * clinical_spn_lb * ( ///
((1 - pcv_vec_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_48_59) * ipd_cases_48_59))
gen spn_pneumonia_cases_ub_d = pna_episodes * clinical_spn_ub * ( ///
((1 - pcv_vec_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_48_59) * ipd_cases_48_59))

* Uncertainty (No vaccine use)
gen hib_pneumonia_cases_lb_n = pna_episodes * clinical_hib_lb
gen hib_pneumonia_cases_ub_n = pna_episodes * clinical_hib_ub 
gen spn_pneumonia_cases_lb_n = pna_episodes * clinical_spn_lb 
gen spn_pneumonia_cases_ub_n = pna_episodes * clinical_spn_ub 

* HIV
foreach effect in "" "_d" "_n" {
	gen hib_pneumonia_cases_hiv`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_cases`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_pneumonia_cases_hiv`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_cases`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen hib_pneumonia_cases_hiv_lb`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_cases_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen hib_pneumonia_cases_hiv_ub`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_cases_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_pneumonia_cases_hiv_lb`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_cases_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen spn_pneumonia_cases_hiv_ub`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_cases_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
}
* 

* Total pathogen-specific pneumonia cases (HIV- and HIV+)
foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" { // Indirect and Direct Effects
		gen `pathogen'_pneumonia_cases_total`effect' = `pathogen'_pneumonia_cases_hiv`effect' + `pathogen'_pneumonia_cases`effect'
		gen `pathogen'_pneumonia_cases_total_lb`effect' = `pathogen'_pneumonia_cases_hiv_lb`effect' + `pathogen'_pneumonia_cases_lb`effect'
		gen `pathogen'_pneumonia_cases_total_ub`effect' = `pathogen'_pneumonia_cases_hiv_ub`effect' + `pathogen'_pneumonia_cases_ub`effect'
	}
}
*

* Severe Pneumonia

* Get point estimates (Indirect Effects)
gen hib_pneumonia_cases_sev = pna_episodes_sev  * severe_hib * (1 - hib3_vec_ind_adj)
gen spn_pneumonia_cases_sev = pna_episodes_sev  * severe_spn * ( ///
((1 - pcv_vec_ind_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_cases_48_59))

* Get point estimates (Direct Effects)
gen hib_pneumonia_cases_sev_d = pna_episodes_sev  * severe_hib * (1 - hib3_vec_adj)
gen spn_pneumonia_cases_sev_d = pna_episodes_sev  * severe_spn * ( ///
((1 - pcv_vec_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_48_59) * ipd_cases_48_59))

* Get point estimates (No vaccine use)
gen hib_pneumonia_cases_sev_n = pna_episodes_sev  * severe_hib 
gen spn_pneumonia_cases_sev_n = pna_episodes_sev  * severe_spn 

* Uncertainty (Indirect Effects)
gen hib_pneumonia_cases_sev_lb = pna_episodes_sev * severe_hib_lb * (1 - hib3_vec_ind_adj)
gen hib_pneumonia_cases_sev_ub = pna_episodes_sev * severe_hib_ub * (1 - hib3_vec_ind_adj)
gen spn_pneumonia_cases_sev_lb = pna_episodes_sev * severe_spn_lb * ( ///
((1 - pcv_vec_ind_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_cases_48_59))
gen spn_pneumonia_cases_sev_ub = pna_episodes_sev * severe_spn_ub * ( ///
((1 - pcv_vec_ind_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_ind_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_ind_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_ind_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_ind_48_59) * ipd_cases_48_59))

* Uncertainty (Direct Effects)
gen hib_pneumonia_cases_sev_lb_d = pna_episodes_sev * severe_hib_lb * (1 - hib3_vec_adj)
gen hib_pneumonia_cases_sev_ub_d = pna_episodes_sev * severe_hib_ub * (1 - hib3_vec_adj)
gen spn_pneumonia_cases_sev_lb_d = pna_episodes_sev * severe_spn_lb * ( ///
((1 - pcv_vec_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_48_59) * ipd_cases_48_59))
gen spn_pneumonia_cases_sev_ub_d = pna_episodes_sev * severe_spn_ub * ( ///
((1 - pcv_vec_2_11) * ipd_cases_1_11) + ///
((1 - pcv_vec_12_23) * ipd_cases_12_23) + ///
((1 - pcv_vec_24_35) * ipd_cases_24_35) + ///
((1 - pcv_vec_36_47) * ipd_cases_36_47) + ///
((1 - pcv_vec_48_59) * ipd_cases_48_59))

* Uncertainty (No vaccine use)
gen hib_pneumonia_cases_sev_lb_n = pna_episodes_sev * severe_hib_lb
gen hib_pneumonia_cases_sev_ub_n = pna_episodes_sev * severe_hib_ub 
gen spn_pneumonia_cases_sev_lb_n = pna_episodes_sev * severe_spn_lb 
gen spn_pneumonia_cases_sev_ub_n = pna_episodes_sev * severe_spn_ub 

* HIV
foreach effect in "" "_d" "_n" {
	gen hib_pneumonia_cases_sev_hiv`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_cases_sev`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_pneumonia_cases_sev_hiv`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_cases_sev`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen hib_pneumonia_cases_sev_hiv_lb`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_cases_sev_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen hib_pneumonia_cases_sev_hiv_ub`effect' = pop_1_59 * hiv_prev * ((hib_pneumonia_cases_sev_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_pneumonia_cases_sev_hiv_lb`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_cases_sev_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen spn_pneumonia_cases_sev_hiv_ub`effect' = pop_1_59 * hiv_prev * ((spn_pneumonia_cases_sev_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
}
*

* Total pathogen-specific pneumonia cases (HIV- and HIV+)
foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" { // Indirect and Direct Effects
		gen `pathogen'_pneumonia_cases_sev_total`effect' = `pathogen'_pneumonia_cases_sev_hiv`effect' + `pathogen'_pneumonia_cases_sev`effect'
		capture gen `pathogen'_pneumonia_cases_sev_total_lb`effect' = `pathogen'_pneumonia_cases_sev_hiv_lb`effect' + `pathogen'_pneumonia_cases_sev_lb`effect'
		capture gen `pathogen'_pneumonia_cases_sev_total_ub`effect' = `pathogen'_pneumonia_cases_sev_hiv_ub`effect' + `pathogen'_pneumonia_cases_sev_ub`effect'
	}
}
cd ".."


********************************************************************************

*	I. Meningitis mortality estimates (HIV- and HIV+) and uncertainty ranges (Proportion)

* Import results of meta-analysis for 'other'
capture cd "./3. Meningitis"
preserve
import delimited using "meningitis_proportion_other_ma.csv", clear
quietly sum proportion
local proportion_other = r(mean)
quietly sum proportion_lb
local proportion_lb = r(mean)
quietly sum proportion_ub
local proportion_ub = r(mean)
restore
gen prop_other = `proportion_other'
gen prop_other_lb_ma = `proportion_lb'
gen prop_other_ub_ma = `proportion_ub'

* Import proportion of cases due to each pathogen
preserve
import delimited "meningitis_proportion_ma.csv", clear
drop proportion_se number i2
reshape wide proportion proportion_lb proportion_ub, i(region) j(pathogen) string
save "case_proportion.dta", replace
restore
merge m:m region using "case_proportion.dta"
drop _merge
foreach pathogen in hib spn nm {
	rename proportion`pathogen' prop_`pathogen'
	rename proportion_lb`pathogen' prop_`pathogen'_lb_ma
	rename proportion_ub`pathogen' prop_`pathogen'_ub_ma
}
erase "case_proportion.dta"

* Import CFR meta-analysis results
preserve
import delimited "meningitis_cfr_ma.csv", clear
drop cfr_se i2
reshape wide cfr cfr_lb cfr_ub, i(mortality_stratum) j(pathogen) string
save "cfr_wide.dta"
restore
merge m:m mortality_stratum using "cfr_wide.dta"
drop _merge
foreach pathogen in hib spn nm {
	rename cfr`pathogen' cfr_`pathogen'
	rename cfr_lb`pathogen' cfr_`pathogen'_lb_ma
	rename cfr_ub`pathogen' cfr_`pathogen'_ub_ma
	replace cfr_`pathogen' = (cfr_`pathogen' * access_to_care) + (0.9 * (1-access_to_care))
	replace cfr_`pathogen'_lb = (cfr_`pathogen'_lb * access_to_care) + (0.9 * (1-access_to_care))
	replace cfr_`pathogen'_ub = (cfr_`pathogen'_ub * access_to_care) + (0.9 * (1-access_to_care))
}
erase "cfr_wide.dta"
sort whoname year
encode whoname, gen(country)
order year iso3 whoname country
sort whoname year
gen _mi_miss = . 
mi unset
tsset country year, year
tssmooth ma cfr_hib_sm = cfr_hib, weights(1 2 3 <4> 3 2 1) 
tssmooth ma cfr_spn_sm = cfr_spn, weights(1 2 3 <4> 3 2 1) 
tssmooth ma cfr_nm_sm = cfr_nm, weights(1 2 3 <4> 3 2 1) 
replace cfr_hib = cfr_hib_sm
replace cfr_spn = cfr_spn_sm
replace cfr_nm = cfr_nm_sm

* Get proportion of deaths by adjusting for relative CFR
gen denom = ((prop_hib * cfr_hib) + (prop_spn * cfr_spn) + (prop_nm * cfr_nm))
foreach pathogen in hib spn nm {
	gen prop_`pathogen'_deaths = (prop_`pathogen' * cfr_`pathogen')/denom
}
*

* Fit proportion of deaths with all pathogens (including "other"; assumes CFR for "other" is an average of three pathogens)
gen denom_other = 1 - prop_other
foreach pathogen in hib spn nm {
	gen prop_`pathogen'_deaths_norm = prop_`pathogen'_deaths * denom_other
}
*

* Undo vaccine use for pneumonia in VR (i.e., non-post-hoc adjustment) countries
gen pn_meningitis_adj = pn_meningitis_no_epi
replace pn_meningitis_adj = pn_meningitis_no_epi / ///
(((1 - (hib3_vec_ind_adj * prop_hib_deaths_norm)) * ///
(1 - (men_vec * prop_nm_deaths_norm))) * ///
(((1 - pcv_vec_ind_2_11 * prop_spn_deaths_norm) * men_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23 * prop_spn_deaths_norm) * men_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35 * prop_spn_deaths_norm) * men_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47 * prop_spn_deaths_norm) * men_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59 * prop_spn_deaths_norm) * men_deaths_48_59))) ///
if meth == "good vr" | meth == "other" | meth == "vrmcm"

* We assume all Hib deaths occur among children less than two years of age. 
* Since we don't have age stratified deaths, we first need to estimate the 
* number of meningitis deaths. 
gen pn_meningitis_adj_1_23 = pn_meningitis_adj/ratio_1_23 

* Point estimates: Indirect Effects 
gen hib_meningitis_deaths = pn_meningitis_adj_1_23 * prop_hib_deaths_norm * (1 - hib3_vec_ind_adj)
gen spn_meningitis_deaths = pn_meningitis_adj * prop_spn_deaths_norm * ( ///
((1 - pcv_vec_ind_2_11) * men_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23) * men_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35) * men_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47) * men_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59) * men_deaths_48_59))
gen nm_meningitis_deaths = pn_meningitis_adj * prop_nm_deaths_norm * (1 - men_vec)
gen nm_meningitis_deaths_epi = pn_meningitis_epi_deaths * (1 - men_vec_epi) 
gen nm_meningitis_death_total = nm_meningitis_deaths + nm_meningitis_deaths_epi

* Point estimates: Direct Effects 
gen hib_meningitis_deaths_d = pn_meningitis_adj_1_23 * prop_hib_deaths_norm * (1 - hib3_vec_adj)
gen spn_meningitis_deaths_d = pn_meningitis_adj * prop_spn_deaths_norm * ( ///
((1 - pcv_vec_2_11) * men_deaths_1_11) + ///
((1 - pcv_vec_12_23) * men_deaths_12_23) + ///
((1 - pcv_vec_24_35) * men_deaths_24_35) + ///
((1 - pcv_vec_36_47) * men_deaths_36_47) + ///
((1 - pcv_vec_48_59) * men_deaths_48_59))

* Point estimates: No Vaccine  
gen hib_meningitis_deaths_n = pn_meningitis_adj_1_23 * prop_hib_deaths_norm
gen spn_meningitis_deaths_n = pn_meningitis_adj * prop_spn_deaths_norm 
gen nm_meningitis_deaths_n = pn_meningitis_adj * prop_nm_deaths_norm 
gen nm_meningitis_deaths_epi_n = pn_meningitis_epi_deaths  
gen nm_meningitis_death_total_n = nm_meningitis_deaths_n + nm_meningitis_deaths_epi_n

* Apply algorithm for determining lower and upper bounds

* "Other" lower and upper bounds
preserve
import delimited using "meningitis_proportion_other_jackknife.csv", clear
quietly centile proportion, centile(2.5 97.5)
local lb = r(c_1)
local ub = r(c_2)
restore 
gen prop_other_lb_jk = `lb'
gen prop_other_ub_jk = `ub'
egen prop_other_lb = rowmin(prop_other_lb_ma prop_other_lb_jk)
egen prop_other_ub = rowmax(prop_other_ub_ma prop_other_ub_jk)

* Proportions lower and upper bounds
preserve
import delimited "meningitis_proportion_jackknife.csv", varnames(1) clear
destring proportion proportion_se proportion_lb proportion_ub, replace
drop study proportion_se proportion_lb proportion_ub
bysort pathogen region: egen proportion_lb_jk = pctile(proportion), p(2.5)
bysort pathogen region: egen proportion_ub_jk = pctile(proportion), p(97.5)
bysort pathogen region: gen counter = _n
drop if counter != 1
drop counter proportion i2
reshape wide proportion_lb_jk proportion_ub_jk, i(region) j(pathogen) string
foreach pathogen in hib spn nm {
	rename proportion_lb_jk`pathogen' prop_`pathogen'_lb_jk
	rename proportion_ub_jk`pathogen' prop_`pathogen'_ub_jk
}
save "meningitis_proportion_jk.dta", replace
restore
merge m:m region using "meningitis_proportion_jk.dta", nogen 
erase "meningitis_proportion_jk.dta"

foreach pathogen in hib spn nm {
	egen prop_`pathogen'_lb = rowmin(prop_`pathogen'_lb_ma prop_`pathogen'_lb_jk)
	egen prop_`pathogen'_ub = rowmax(prop_`pathogen'_ub_ma prop_`pathogen'_ub_jk) 
}
*

* CFR lower and upper bounds
preserve 
import delimited "meningitis_cfr_jackknife.csv", clear
drop study cfr_se cfr_lb cfr_ub
bysort pathogen mortality_stratum: egen cfr_lb_jk = pctile(cfr), p(2.5)
bysort pathogen mortality_stratum: egen cfr_ub_jk = pctile(cfr), p(97.5)
bysort pathogen mortality_stratum: gen counter = _n
drop if counter != 1
drop counter cfr i2
reshape wide cfr_lb_jk cfr_ub_jk, i(mortality_stratum) j(pathogen) string
foreach pathogen in hib spn nm {
	rename cfr_lb_jk`pathogen' cfr_`pathogen'_lb_jk
	rename cfr_ub_jk`pathogen' cfr_`pathogen'_ub_jk
}
save "meningitis_cfr_jk.dta", replace
restore
merge m:m mortality_stratum using "meningitis_cfr_jk.dta", nogen
erase "meningitis_cfr_jk.dta"
foreach pathogen in hib spn nm {
	egen cfr_`pathogen'_lb = rowmin(cfr_`pathogen'_lb_ma cfr_`pathogen'_lb_jk)
	egen cfr_`pathogen'_ub = rowmax(cfr_`pathogen'_ub_ma cfr_`pathogen'_ub_jk)  
}
sort iso3 year
foreach b in lb ub {
	foreach m in ma jk {
		drop prop_other_`b'_`m'
		drop prop_hib_`b'_`m'
		drop prop_spn_`b'_`m'
		drop prop_nm_`b'_`m'
		drop cfr_hib_`b'_`m'
		drop cfr_spn_`b'_`m'
		drop cfr_nm_`b'_`m'
	}
}
*

* Get uncertainty ranges for proportions
gen denom_other_lb = 1 - prop_other_ub // For use with lower bound estimates
gen denom_other_ub = 1 - prop_other_lb // For use with upper bound estimates

gen denom_hib_lb = ((prop_hib_lb * cfr_hib_lb) + (prop_spn_ub * cfr_spn_ub) + (prop_nm_ub * cfr_nm_ub))
gen denom_hib_ub = ((prop_hib_ub * cfr_hib_ub) + (prop_spn_lb * cfr_spn_lb) + (prop_nm_lb * cfr_nm_lb))
gen denom_spn_lb = ((prop_spn_lb * cfr_spn_lb) + (prop_hib_ub * cfr_hib_ub) + (prop_nm_ub * cfr_nm_ub))
gen denom_spn_ub = ((prop_spn_ub * cfr_spn_ub) + (prop_hib_lb * cfr_hib_lb) + (prop_nm_lb * cfr_nm_lb))
gen denom_nm_lb = ((prop_nm_lb * cfr_nm_lb) + (prop_hib_ub * cfr_hib_ub) + (prop_spn_ub * cfr_spn_ub))
gen denom_nm_ub = ((prop_nm_ub * cfr_nm_ub) + (prop_hib_lb * cfr_hib_lb) + (prop_spn_lb * cfr_spn_lb))

foreach pathogen in hib spn nm {
	gen prop_`pathogen'_deaths_lb = (prop_`pathogen'_lb * cfr_`pathogen'_lb)/denom_`pathogen'_lb
	gen prop_`pathogen'_deaths_ub = (prop_`pathogen'_ub * cfr_`pathogen'_ub)/denom_`pathogen'_ub
}
*

foreach pathogen in hib spn nm {
	gen prop_`pathogen'_deaths_lb_norm = prop_`pathogen'_deaths_lb * denom_other_lb
	gen prop_`pathogen'_deaths_ub_norm = prop_`pathogen'_deaths_ub * denom_other_ub
}
*

* Uncertainty ranges: Indirect Effects
gen hib_meningitis_deaths_lb = pn_meningitis_adj_1_23 * prop_hib_deaths_lb_norm * (1 - hib3_vec_ind_adj)
gen hib_meningitis_deaths_ub = pn_meningitis_adj_1_23 * prop_hib_deaths_ub_norm * (1 - hib3_vec_ind_adj)
gen spn_meningitis_deaths_lb = pn_meningitis_adj * prop_spn_deaths_lb_norm * ( ///
((1 - pcv_vec_ind_2_11) * men_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23) * men_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35) * men_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47) * men_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59) * men_deaths_48_59))
gen spn_meningitis_deaths_ub = pn_meningitis_adj * prop_spn_deaths_ub_norm * ( ///
((1 - pcv_vec_ind_2_11) * men_deaths_1_11) + ///
((1 - pcv_vec_ind_12_23) * men_deaths_12_23) + ///
((1 - pcv_vec_ind_24_35) * men_deaths_24_35) + ///
((1 - pcv_vec_ind_36_47) * men_deaths_36_47) + ///
((1 - pcv_vec_ind_48_59) * men_deaths_48_59))
gen nm_meningitis_deaths_lb = pn_meningitis_adj * prop_nm_deaths_lb_norm * (1 - men_vec)
gen nm_meningitis_deaths_ub = pn_meningitis_adj * prop_nm_deaths_ub_norm * (1 - men_vec)

* Uncertainty ranges: Direct Effects
gen hib_meningitis_deaths_lb_d = pn_meningitis_adj_1_23 * prop_hib_deaths_lb_norm * (1 - hib3_vec_adj)
gen hib_meningitis_deaths_ub_d = pn_meningitis_adj_1_23 * prop_hib_deaths_ub_norm * (1 - hib3_vec_adj)
gen spn_meningitis_deaths_lb_d = pn_meningitis_adj * prop_spn_deaths_lb_norm * ( ///
((1 - pcv_vec_2_11) * men_deaths_1_11) + ///
((1 - pcv_vec_12_23) * men_deaths_12_23) + ///
((1 - pcv_vec_24_35) * men_deaths_24_35) + ///
((1 - pcv_vec_36_47) * men_deaths_36_47) + ///
((1 - pcv_vec_48_59) * men_deaths_48_59))
gen spn_meningitis_deaths_ub_d = pn_meningitis_adj * prop_spn_deaths_ub_norm * ( ///
((1 - pcv_vec_2_11) * men_deaths_1_11) + ///
((1 - pcv_vec_12_23) * men_deaths_12_23) + ///
((1 - pcv_vec_24_35) * men_deaths_24_35) + ///
((1 - pcv_vec_36_47) * men_deaths_36_47) + ///
((1 - pcv_vec_48_59) * men_deaths_48_59))

* Uncertainty ranges: No vaccine
gen hib_meningitis_deaths_lb_n = pn_meningitis_adj_1_23 * prop_hib_deaths_lb_norm 
gen hib_meningitis_deaths_ub_n = pn_meningitis_adj_1_23 * prop_hib_deaths_ub_norm 
gen spn_meningitis_deaths_lb_n = pn_meningitis_adj * prop_spn_deaths_lb_norm 
gen spn_meningitis_deaths_ub_n = pn_meningitis_adj * prop_spn_deaths_ub_norm 
gen nm_meningitis_deaths_lb_n = pn_meningitis_adj * prop_nm_deaths_lb_norm 
gen nm_meningitis_deaths_ub_n = pn_meningitis_adj * prop_nm_deaths_ub_norm 


* Meningitis HIV Estimates: Indirect Effects
foreach effect in "" "_d" "_n" {
	gen hib_meningitis_deaths_hiv`effect' = pop_1_59 * hiv_prev * ((hib_meningitis_deaths`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_meningitis_deaths_hiv`effect' = pop_1_59 * hiv_prev * ((spn_meningitis_deaths`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen hib_meningitis_deaths_hiv_lb`effect' = pop_1_59 * hiv_prev * ((hib_meningitis_deaths_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen hib_meningitis_deaths_hiv_ub`effect' = pop_1_59 * hiv_prev * ((hib_meningitis_deaths_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $hib_hiv_rr
	gen spn_meningitis_deaths_hiv_lb`effect' = pop_1_59 * hiv_prev * ((spn_meningitis_deaths_lb`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
	gen spn_meningitis_deaths_hiv_ub`effect' = pop_1_59 * hiv_prev * ((spn_meningitis_deaths_ub`effect')/((1 - hiv_prev) * (pop_1_59))) * $spn_hiv_rr
}
*

gen nm_meningitis_deaths_hiv = pop_1_59 * hiv_prev * ((nm_meningitis_deaths)/((1 - hiv_prev) * (pop_1_59))) * $nm_hiv_rr
gen nm_meningitis_deaths_hiv_lb = pop_1_59 * hiv_prev * ((nm_meningitis_deaths_lb)/((1 - hiv_prev) * (pop_1_59))) * $nm_hiv_rr
gen nm_meningitis_deaths_hiv_ub = pop_1_59 * hiv_prev * ((nm_meningitis_deaths_ub)/((1 - hiv_prev) * (pop_1_59))) * $nm_hiv_rr
gen nm_meningitis_deaths_hiv_n = pop_1_59 * hiv_prev * ((nm_meningitis_deaths_n)/((1 - hiv_prev) * (pop_1_59))) * $nm_hiv_rr
gen nm_meningitis_deaths_hiv_lb_n = pop_1_59 * hiv_prev * ((nm_meningitis_deaths_lb_n)/((1 - hiv_prev) * (pop_1_59))) * $nm_hiv_rr
gen nm_meningitis_deaths_hiv_ub_n = pop_1_59 * hiv_prev * ((nm_meningitis_deaths_ub_n)/((1 - hiv_prev) * (pop_1_59))) * $nm_hiv_rr

* Total pathogen-specific meningitis deaths (HIV- and HIV+)
foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" {
		gen `pathogen'_meningitis_deaths_total`effect' = `pathogen'_meningitis_deaths_hiv`effect' + `pathogen'_meningitis_deaths`effect'
		gen `pathogen'_meningitis_deaths_total_lb`effect' = `pathogen'_meningitis_deaths_hiv_lb`effect' + `pathogen'_meningitis_deaths_lb`effect'
		gen `pathogen'_meningitis_deaths_total_ub`effect' = `pathogen'_meningitis_deaths_hiv_ub`effect' + `pathogen'_meningitis_deaths_ub`effect'
	}	
}
*
gen nm_meningitis_deaths_total = nm_meningitis_deaths_hiv + nm_meningitis_deaths
gen nm_meningitis_deaths_total_lb = nm_meningitis_deaths_hiv_lb + nm_meningitis_deaths_lb
gen nm_meningitis_deaths_total_ub = nm_meningitis_deaths_hiv_ub + nm_meningitis_deaths_ub
gen nm_meningitis_deaths_total_n = nm_meningitis_deaths_hiv_n + nm_meningitis_deaths_n
gen nm_meningitis_deaths_total_lb_n = nm_meningitis_deaths_hiv_lb_n + nm_meningitis_deaths_lb_n
gen nm_meningitis_deaths_total_ub_n = nm_meningitis_deaths_hiv_ub_n + nm_meningitis_deaths_ub_n

cd ".."

********************************************************************************

* 	J. Meningitis morbidity estimates (HIV- and HIV+) and uncertainty ranges (Proportion)

foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" {
		gen `pathogen'_meningitis_cases`effect' = `pathogen'_meningitis_deaths`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_lb`effect' = `pathogen'_meningitis_deaths_lb`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_ub`effect' = `pathogen'_meningitis_deaths_ub`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_hiv`effect' = `pathogen'_meningitis_deaths_hiv`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_hiv_lb`effect' = `pathogen'_meningitis_deaths_hiv_lb`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_hiv_ub`effect' = `pathogen'_meningitis_deaths_hiv_ub`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_total`effect' = `pathogen'_meningitis_deaths_total`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_total_lb`effect' = `pathogen'_meningitis_deaths_total_lb`effect' / cfr_`pathogen'
		gen `pathogen'_meningitis_cases_total_ub`effect' = `pathogen'_meningitis_deaths_total_ub`effect' / cfr_`pathogen'	

	}
}
*
gen nm_meningitis_cases = nm_meningitis_deaths / cfr_nm
gen nm_meningitis_cases_lb = nm_meningitis_deaths_lb / cfr_nm
gen nm_meningitis_cases_ub = nm_meningitis_deaths_ub / cfr_nm
gen nm_meningitis_cases_hiv = nm_meningitis_deaths_hiv / cfr_nm
gen nm_meningitis_cases_hiv_lb = nm_meningitis_deaths_hiv_lb / cfr_nm
gen nm_meningitis_cases_hiv_ub = nm_meningitis_deaths_hiv_ub / cfr_nm
gen nm_meningitis_cases_total = nm_meningitis_deaths_total / cfr_nm
gen nm_meningitis_cases_total_lb = nm_meningitis_deaths_total_lb / cfr_nm
gen nm_meningitis_cases_total_ub = nm_meningitis_deaths_total_ub / cfr_nm

gen nm_meningitis_cases_n = nm_meningitis_deaths_n / cfr_nm
gen nm_meningitis_cases_lb_n = nm_meningitis_deaths_lb_n / cfr_nm
gen nm_meningitis_cases_ub_n = nm_meningitis_deaths_ub_n / cfr_nm
gen nm_meningitis_cases_hiv_n = nm_meningitis_deaths_hiv_n / cfr_nm
gen nm_meningitis_cases_hiv_lb_n = nm_meningitis_deaths_hiv_lb_n / cfr_nm
gen nm_meningitis_cases_hiv_ub_n = nm_meningitis_deaths_hiv_ub_n / cfr_nm
gen nm_meningitis_cases_total_n = nm_meningitis_deaths_total_n / cfr_nm
gen nm_meningitis_cases_total_lb_n = nm_meningitis_deaths_total_lb_n / cfr_nm
gen nm_meningitis_cases_total_ub_n = nm_meningitis_deaths_total_ub_n / cfr_nm


********************************************************************************

*	M. NPNM morbidity estimates (HIV- and HIV+) and uncertainty ranges

* Importing estimates from MA

* Multiplier for severe NPNM
cd "./4. NPNM"
preserve 
import delimited using "npnm_ma.csv", clear
drop inc_multiplier_se studies severity
rename mortality_strata mortality_stratum
reshape wide inc_multiplier, i(mortality_stratum) j(pathogen) string
foreach pathogen in hib spn {
	rename inc_multiplier`pathogen' multi_`pathogen'_sev
}
*
save "npnm.dta", replace
restore
sort iso3 year
merge m:1 mortality_stratum using "npnm.dta", nogen
erase "npnm.dta"

* Multiplier for non-severe NPNM
preserve 
import delimited using "npnm_nonsevere_ma.csv", clear
sum inc_multiplier
local multi_spn_nonsev = r(mean)
restore
gen multi_spn_nonsev = `multi_spn_nonsev'

* CFR multiplier for severe NPNM
preserve
import delimited using "npnm_cfr_ma.csv", clear
drop cfr_multiplier_se cfr_multiplier_low cfr_multiplier_upp studies
foreach pathogen in hib spn {
	sum cfr_multiplier if pathogen == "`pathogen'"
	local cfr_multi_`pathogen'_sev = r(mean)
}
restore
gen cfr_multi_hib_sev = `cfr_multi_hib_sev'
gen cfr_multi_spn_sev = `cfr_multi_spn_sev'
sort iso3 year

* Estimate NPNM severe cases with uncertainty ranges
foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" {
		gen `pathogen'_npnm_cases`effect' = `pathogen'_meningitis_cases`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_lb`effect' = `pathogen'_meningitis_cases_lb`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_ub`effect' = `pathogen'_meningitis_cases_ub`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_hiv`effect' = `pathogen'_meningitis_cases_hiv`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_hiv_lb`effect' = `pathogen'_meningitis_cases_hiv_lb`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_hiv_ub`effect' = `pathogen'_meningitis_cases_hiv_ub`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_total`effect' = `pathogen'_meningitis_cases_total`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_total_lb`effect' = `pathogen'_meningitis_cases_total_lb`effect' * multi_`pathogen'_sev
		gen `pathogen'_npnm_cases_total_ub`effect' = `pathogen'_meningitis_cases_total_ub`effect' * multi_`pathogen'_sev
	}
}
*

* Estimate NPNM non-severe cases with uncertainty ranges
foreach effect in "" "_d" "_n" {
	gen spn_npnm_cases_nonsev`effect' = spn_meningitis_cases`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_lb`effect' = spn_meningitis_cases_lb`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_ub`effect' = spn_meningitis_cases_ub`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_hiv`effect' = spn_meningitis_cases_hiv`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_hiv_lb`effect' = spn_meningitis_cases_hiv_lb`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_hiv_ub`effect' = spn_meningitis_cases_hiv_ub`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_total`effect' = spn_meningitis_cases_total`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_total_lb`effect' = spn_meningitis_cases_total_lb`effect' * multi_spn_nonsev
	gen spn_npnm_cases_nonsev_total_ub`effect' = spn_meningitis_cases_total_ub`effect' * multi_spn_nonsev
}
*

********************************************************************************

*	N. NPNM mortality estimates (HIV- and HIV+) and uncertainty ranges

* Country specific NPNM CFR
foreach pathogen in hib spn {
	gen npnm_cfr_`pathogen' = cfr_`pathogen' * cfr_multi_`pathogen'_sev
}
*

* Estimates NPNM severe deaths with uncertainty ranges
foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" {
		gen	`pathogen'_npnm_deaths`effect' = `pathogen'_npnm_cases`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_lb`effect' = `pathogen'_npnm_cases_lb`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_ub`effect' = `pathogen'_npnm_cases_ub`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_hiv`effect' = `pathogen'_npnm_cases_hiv`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_hiv_lb`effect' = `pathogen'_npnm_cases_hiv_lb`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_hiv_ub`effect' = `pathogen'_npnm_cases_hiv_ub`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_total`effect' = `pathogen'_npnm_cases_total`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_total_lb`effect' = `pathogen'_npnm_cases_total_lb`effect' * npnm_cfr_`pathogen'
		gen `pathogen'_npnm_deaths_total_ub`effect' = `pathogen'_npnm_cases_total_ub`effect' * npnm_cfr_`pathogen'
	}
}
*

cd ".."

********************************************************************************

* N. Totals

foreach pathogen in hib spn {
	foreach effect in "" "_d" "_n" {
		gen `pathogen'_deaths`effect' = `pathogen'_pneumonia_deaths`effect' + `pathogen'_meningitis_deaths`effect' + `pathogen'_npnm_deaths`effect'
		gen `pathogen'_deaths_lb`effect' = `pathogen'_pneumonia_deaths_lb`effect' + `pathogen'_meningitis_deaths_lb`effect' + `pathogen'_npnm_deaths_lb`effect'
		gen `pathogen'_deaths_ub`effect' = `pathogen'_pneumonia_deaths_ub`effect' + `pathogen'_meningitis_deaths_ub`effect' + `pathogen'_npnm_deaths_ub`effect'
		gen `pathogen'_deaths_hiv`effect' = `pathogen'_pneumonia_deaths_hiv`effect' + `pathogen'_meningitis_deaths_hiv`effect' + `pathogen'_npnm_deaths_hiv`effect'
		gen `pathogen'_deaths_hiv_lb`effect' = `pathogen'_pneumonia_deaths_hiv_lb`effect' + `pathogen'_meningitis_deaths_hiv_lb`effect' + `pathogen'_npnm_deaths_hiv_lb`effect'
		gen `pathogen'_deaths_hiv_ub`effect' = `pathogen'_pneumonia_deaths_hiv_ub`effect' + `pathogen'_meningitis_deaths_hiv_ub`effect' + `pathogen'_npnm_deaths_hiv_ub`effect'
		gen `pathogen'_deaths_total`effect' = `pathogen'_pneumonia_deaths_total`effect' + `pathogen'_meningitis_deaths_total`effect' + `pathogen'_npnm_deaths_total`effect'
		gen `pathogen'_deaths_total_lb`effect' = `pathogen'_pneumonia_deaths_total_lb`effect' + `pathogen'_meningitis_deaths_total_lb`effect' + `pathogen'_npnm_deaths_total_lb`effect'
		gen `pathogen'_deaths_total_ub`effect' = `pathogen'_pneumonia_deaths_total_ub`effect' + `pathogen'_meningitis_deaths_total_ub`effect' + `pathogen'_npnm_deaths_total_ub`effect'
	}
}
*

foreach pathogen in hib spn {
	gen `pathogen'_cases_sev = `pathogen'_pneumonia_cases_sev + `pathogen'_meningitis_cases + `pathogen'_npnm_cases
	gen `pathogen'_cases_sev_lb = `pathogen'_pneumonia_cases_sev_lb + `pathogen'_meningitis_cases_lb + `pathogen'_npnm_cases_lb
	gen `pathogen'_cases_sev_ub = `pathogen'_pneumonia_cases_sev_ub + `pathogen'_meningitis_cases_ub + `pathogen'_npnm_cases_ub
	gen `pathogen'_cases_sev_hiv = `pathogen'_pneumonia_cases_sev_hiv +  `pathogen'_meningitis_cases_hiv  + `pathogen'_npnm_cases_hiv
	gen `pathogen'_cases_sev_hiv_lb = `pathogen'_pneumonia_cases_sev_hiv_lb +  `pathogen'_meningitis_cases_hiv_lb + `pathogen'_npnm_cases_hiv_lb
	gen `pathogen'_cases_sev_hiv_ub = `pathogen'_pneumonia_cases_sev_hiv_ub +  `pathogen'_meningitis_cases_hiv_ub + `pathogen'_npnm_cases_hiv_ub
	gen `pathogen'_cases_sev_total = `pathogen'_pneumonia_cases_sev_total + `pathogen'_meningitis_cases_total + `pathogen'_npnm_cases_total
	gen `pathogen'_cases_sev_total_lb = `pathogen'_pneumonia_cases_sev_total_lb + `pathogen'_meningitis_cases_total_lb + `pathogen'_npnm_cases_total_lb
	gen `pathogen'_cases_sev_total_ub = `pathogen'_pneumonia_cases_sev_total_ub + `pathogen'_meningitis_cases_total_ub + `pathogen'_npnm_cases_total_ub

}
*

gen spn_cases = spn_pneumonia_cases + spn_meningitis_cases + spn_npnm_cases + spn_npnm_cases_nonsev
gen spn_cases_lb = spn_pneumonia_cases_lb + spn_meningitis_cases_lb + spn_npnm_cases_lb + spn_npnm_cases_nonsev_lb
gen spn_cases_ub = spn_pneumonia_cases_ub + spn_meningitis_cases_ub + spn_npnm_cases_ub + spn_npnm_cases_nonsev_ub
gen spn_cases_hiv = spn_pneumonia_cases_hiv +  spn_meningitis_cases_hiv  + spn_npnm_cases_hiv + spn_npnm_cases_nonsev_hiv
gen spn_cases_hiv_lb = spn_pneumonia_cases_hiv_lb +  spn_meningitis_cases_hiv_lb + spn_npnm_cases_hiv_lb + spn_npnm_cases_nonsev_hiv_lb
gen spn_cases_hiv_ub = spn_pneumonia_cases_hiv_ub +  spn_meningitis_cases_hiv_ub + spn_npnm_cases_hiv_ub + spn_npnm_cases_nonsev_hiv_ub
gen spn_cases_total = spn_pneumonia_cases_total + spn_meningitis_cases_total + spn_npnm_cases_total + spn_npnm_cases_nonsev_total
gen spn_cases_total_lb = spn_pneumonia_cases_total_lb + spn_meningitis_cases_total_lb + spn_npnm_cases_total_lb + spn_npnm_cases_nonsev_total_lb
gen spn_cases_total_ub = spn_pneumonia_cases_total_ub + spn_meningitis_cases_total_ub + spn_npnm_cases_total_ub + spn_npnm_cases_nonsev_total_ub

gen hib_cases = hib_pneumonia_cases + hib_meningitis_cases + hib_npnm_cases
gen hib_cases_lb = hib_pneumonia_cases_lb + hib_meningitis_cases_lb + hib_npnm_cases_lb
gen hib_cases_ub = hib_pneumonia_cases_ub + hib_meningitis_cases_ub + hib_npnm_cases_ub
gen hib_cases_hiv = hib_pneumonia_cases_hiv +  hib_meningitis_cases_hiv  + hib_npnm_cases_hiv
gen hib_cases_hiv_lb = hib_pneumonia_cases_hiv_lb +  hib_meningitis_cases_hiv_lb + hib_npnm_cases_hiv_lb
gen hib_cases_hiv_ub = hib_pneumonia_cases_hiv_ub +  hib_meningitis_cases_hiv_ub + hib_npnm_cases_hiv_ub
gen hib_cases_total = hib_pneumonia_cases_total + hib_meningitis_cases_total + hib_npnm_cases_total
gen hib_cases_total_lb = hib_pneumonia_cases_total_lb + hib_meningitis_cases_total_lb + hib_npnm_cases_total_lb
gen hib_cases_total_ub = hib_pneumonia_cases_total_ub + hib_meningitis_cases_total_ub + hib_npnm_cases_total_ub

*
********************************************************************************

* O. Some India stuff for the state-by-state analysis

save "countries_time_series_results.dta", replace
use "india_state_collapsed.dta"

* Merge in the state model results for India
use "countries_time_series_results.dta", clear
replace iso3 = "IND1" if iso3 == "IND"
capture drop _merge
merge 1:1 year iso3 using "india_state_collapsed.dta"
sort whoname year
replace nmr = (neonatal_deaths/live_births) * 1000 if iso3 == "IND"
replace imr = (infant_deaths/live_births) * 1000 if iso3 == "IND"
replace u5mr = (u5_deaths/live_births) * 1000 if iso3 == "IND"
replace mortality_stratum = "1.Very Low" if  u5mr < 30 & mortality_stratum == ""
replace mortality_stratum = "2.Medium" if  u5mr >= 30 & u5mr < 75 & mortality_stratum == ""
replace mortality_stratum = "3.High" if  u5mr >= 75 & u5mr < 150 & mortality_stratum == ""
replace mortality_stratum = "4.Very High" if u5mr >= 150 & mortality_stratum == ""

* Clean up some meningitis stuff
cd "./3. Meningitis"
foreach pathogen in hib spn {
	foreach outcome in inc cfr {
		forval i = 0/4 {
			 capture erase "`pathogen'_`outcome'_index_`i'.csv" 
			 capture erase "`pathogen'_`outcome'_index_`i'_jackknife.csv"
		}
	}
}
cd ".."
*

********************************************************************************

* OP. Death and Incidence Rates

replace pop_1_59 = u5_pop_norm if iso3 == "IND"
drop u5_pop_norm
drop if iso3 == "IND1"

foreach pathogen in hib spn {
	replace `pathogen'_deaths = `pathogen'_pneumonia_deaths + `pathogen'_meningitis_deaths + `pathogen'_npnm_deaths if whoname == "India"
	replace `pathogen'_deaths_lb = `pathogen'_pneumonia_deaths_lb + `pathogen'_meningitis_deaths_lb + `pathogen'_npnm_deaths_lb if whoname == "India"
	replace `pathogen'_deaths_ub = `pathogen'_pneumonia_deaths_ub + `pathogen'_meningitis_deaths_ub + `pathogen'_npnm_deaths_ub if whoname == "India"
	replace `pathogen'_deaths_hiv = `pathogen'_pneumonia_deaths_hiv + `pathogen'_meningitis_deaths_hiv + `pathogen'_npnm_deaths_hiv if whoname == "India"
	replace `pathogen'_deaths_hiv_lb = `pathogen'_pneumonia_deaths_hiv_lb + `pathogen'_meningitis_deaths_hiv_lb + `pathogen'_npnm_deaths_hiv_lb if whoname == "India"
	replace `pathogen'_deaths_hiv_ub = `pathogen'_pneumonia_deaths_hiv_ub + `pathogen'_meningitis_deaths_hiv_ub + `pathogen'_npnm_deaths_hiv_ub if whoname == "India"
	replace `pathogen'_deaths_total = `pathogen'_pneumonia_deaths_total + `pathogen'_meningitis_deaths_total + `pathogen'_npnm_deaths_total if whoname == "India"
	replace `pathogen'_deaths_total_lb = `pathogen'_pneumonia_deaths_total_lb + `pathogen'_meningitis_deaths_total_lb + `pathogen'_npnm_deaths_total_lb if whoname == "India"
	replace `pathogen'_deaths_total_ub = `pathogen'_pneumonia_deaths_total_ub + `pathogen'_meningitis_deaths_total_ub + `pathogen'_npnm_deaths_total_ub if whoname == "India"
	replace `pathogen'_cases_sev = `pathogen'_pneumonia_cases_sev + `pathogen'_meningitis_cases + `pathogen'_npnm_cases if whoname == "India"
	replace `pathogen'_cases_sev_lb = `pathogen'_pneumonia_cases_sev_lb + `pathogen'_meningitis_cases_lb + `pathogen'_npnm_cases_lb if whoname == "India"
	replace `pathogen'_cases_sev_ub = `pathogen'_pneumonia_cases_sev_ub + `pathogen'_meningitis_cases_ub + `pathogen'_npnm_cases_ub if whoname == "India"
	replace `pathogen'_cases_sev_hiv = `pathogen'_pneumonia_cases_sev_hiv +  `pathogen'_meningitis_cases_hiv  + `pathogen'_npnm_cases_hiv if whoname == "India"
	replace `pathogen'_cases_sev_hiv_lb = `pathogen'_pneumonia_cases_sev_hiv_lb +  `pathogen'_meningitis_cases_hiv_lb  + `pathogen'_npnm_cases_hiv_lb if whoname == "India"
	replace `pathogen'_cases_sev_hiv_ub = `pathogen'_pneumonia_cases_sev_hiv_ub +  `pathogen'_meningitis_cases_hiv_ub  + `pathogen'_npnm_cases_hiv_ub if whoname == "India"
	replace `pathogen'_cases_sev_total = `pathogen'_pneumonia_cases_sev_total + `pathogen'_meningitis_cases_total + `pathogen'_npnm_cases_total if whoname == "India"
	replace `pathogen'_cases_sev_total_lb = `pathogen'_pneumonia_cases_sev_total_lb + `pathogen'_meningitis_cases_total_lb + `pathogen'_npnm_cases_total_lb if whoname == "India"
	replace `pathogen'_cases_sev_total_ub = `pathogen'_pneumonia_cases_sev_total_ub + `pathogen'_meningitis_cases_total_ub + `pathogen'_npnm_cases_total_ub if whoname == "India"
}
*

replace spn_cases = spn_pneumonia_cases + spn_meningitis_cases + spn_npnm_cases + spn_npnm_cases_nonsev if whoname == "India"
replace spn_cases_lb = spn_pneumonia_cases_lb + spn_meningitis_cases_lb + spn_npnm_cases_lb + spn_npnm_cases_nonsev_lb if whoname == "India"
replace spn_cases_ub = spn_pneumonia_cases_ub + spn_meningitis_cases_ub + spn_npnm_cases_ub + spn_npnm_cases_nonsev_ub if whoname == "India"
replace spn_cases_hiv = spn_pneumonia_cases_hiv +  spn_meningitis_cases_hiv  + spn_npnm_cases_hiv + spn_npnm_cases_nonsev_hiv if whoname == "India"
replace spn_cases_hiv_lb = spn_pneumonia_cases_hiv_lb +  spn_meningitis_cases_hiv_lb + spn_npnm_cases_hiv_lb + spn_npnm_cases_nonsev_hiv_lb if whoname == "India"
replace spn_cases_hiv_ub = spn_pneumonia_cases_hiv_ub +  spn_meningitis_cases_hiv_ub + spn_npnm_cases_hiv_ub + spn_npnm_cases_nonsev_hiv_ub if whoname == "India"
replace spn_cases_total = spn_pneumonia_cases_total + spn_meningitis_cases_total + spn_npnm_cases_total + spn_npnm_cases_nonsev_total if whoname == "India"
replace spn_cases_total_lb = spn_pneumonia_cases_total_lb + spn_meningitis_cases_total_lb + spn_npnm_cases_total_lb + spn_npnm_cases_nonsev_total_lb if whoname == "India"
replace spn_cases_total_ub = spn_pneumonia_cases_total_ub + spn_meningitis_cases_total_ub + spn_npnm_cases_total_ub + spn_npnm_cases_nonsev_total_ub if whoname == "India"


replace hib_cases = hib_pneumonia_cases + hib_meningitis_cases + hib_npnm_cases if whoname == "India"
replace hib_cases_lb = hib_pneumonia_cases_lb + hib_meningitis_cases_lb + hib_npnm_cases_lb if whoname == "India"
replace hib_cases_ub = hib_pneumonia_cases_ub + hib_meningitis_cases_ub + hib_npnm_cases_ub if whoname == "India"
replace hib_cases_hiv = hib_pneumonia_cases_hiv + hib_meningitis_cases_hiv + hib_npnm_cases_hiv if whoname == "India"
replace hib_cases_hiv_lb = hib_pneumonia_cases_hiv_lb + hib_meningitis_cases_hiv_lb + hib_npnm_cases_hiv_lb if whoname == "India"
replace hib_cases_hiv_ub = hib_pneumonia_cases_hiv_ub + hib_meningitis_cases_hiv_ub + hib_npnm_cases_hiv_ub if whoname == "India"
replace hib_cases_total = hib_pneumonia_cases_total + hib_meningitis_cases_total + hib_npnm_cases_total if whoname == "India"
replace hib_cases_total_lb = hib_pneumonia_cases_total_lb + hib_meningitis_cases_total_lb + hib_npnm_cases_total_lb if whoname == "India"
replace hib_cases_total_ub = hib_pneumonia_cases_total_ub + hib_meningitis_cases_total_ub + hib_npnm_cases_total_ub if whoname == "India"

* Syndrome-specific rates
foreach pathogen in hib spn {
	foreach syndrome in pneumonia meningitis npnm {
		foreach effect in "" "_d" "_n" {
			gen `pathogen'_`syndrome'_drate`effect' = (`pathogen'_`syndrome'_deaths`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_drate_lb`effect' = (`pathogen'_`syndrome'_deaths_lb`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_drate_ub`effect' = (`pathogen'_`syndrome'_deaths_ub`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_hiv_drate`effect' = (`pathogen'_`syndrome'_deaths_hiv`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_hiv_drate_lb`effect' = (`pathogen'_`syndrome'_deaths_hiv_lb`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_hiv_drate_ub`effect' = (`pathogen'_`syndrome'_deaths_hiv_ub`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_total_drate`effect' = (`pathogen'_`syndrome'_deaths_total`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_total_drate_lb`effect' = (`pathogen'_`syndrome'_deaths_total_lb`effect' / pop_1_59) * 100000
			gen `pathogen'_`syndrome'_total_drate_ub`effect' = (`pathogen'_`syndrome'_deaths_total_ub`effect' / pop_1_59) * 100000
		}
	}
}
*

* NM meningitis death rates
foreach effect in "" "_n" {
	gen nm_meningitis_drate`effect' = (nm_meningitis_deaths`effect' / pop_1_59) * 100000
	gen nm_meningitis_drate_lb`effect' = (nm_meningitis_deaths_lb`effect' / pop_1_59) * 100000
	gen nm_meningitis_drate_ub`effect' = (nm_meningitis_deaths_ub`effect' / pop_1_59) * 100000
	gen nm_meningitis_hiv_drate`effect' = (nm_meningitis_deaths_hiv`effect' / pop_1_59) * 100000
	gen nm_meningitis_hiv_drate_lb`effect' = (nm_meningitis_deaths_hiv_lb`effect' / pop_1_59) * 100000
	gen nm_meningitis_hiv_drate_ub`effect' = (nm_meningitis_deaths_hiv_ub`effect' / pop_1_59) * 100000
	gen nm_meningitis_total_drate`effect' = (nm_meningitis_deaths_total`effect' / pop_1_59) * 100000
	gen nm_meningitis_total_drate_lb`effect' = (nm_meningitis_deaths_total_lb`effect' / pop_1_59) * 100000
	gen nm_meningitis_total_drate_ub`effect' = (nm_meningitis_deaths_total_ub`effect' / pop_1_59) * 100000	
}
*

* Totals and total mortality rates
foreach pathogen in hib spn {
	gen `pathogen'_drate = (`pathogen'_deaths / pop_1_59) * 100000
	gen `pathogen'_drate_lb = (`pathogen'_deaths_lb / pop_1_59) * 100000
	gen `pathogen'_drate_ub = (`pathogen'_deaths_ub / pop_1_59) * 100000
	gen `pathogen'_hiv_drate = (`pathogen'_deaths_hiv / pop_1_59) * 100000
	gen `pathogen'_hiv_drate_lb = (`pathogen'_deaths_hiv_lb / pop_1_59) * 100000
	gen `pathogen'_hiv_drate_ub = (`pathogen'_deaths_hiv_ub / pop_1_59) * 100000
	gen `pathogen'_total_drate = (`pathogen'_deaths_total / pop_1_59) * 100000
	gen `pathogen'_total_drate_lb = (`pathogen'_deaths_total_lb / pop_1_59) * 100000
	gen `pathogen'_total_drate_ub = (`pathogen'_deaths_total_ub / pop_1_59) * 100000
	
	gen `pathogen'_sev_irate = (`pathogen'_cases_sev / pop_1_59) * 100000
	gen `pathogen'_sev_irate_lb = (`pathogen'_cases_sev_lb / pop_1_59) * 100000
	gen `pathogen'_sev_irate_ub = (`pathogen'_cases_sev_ub / pop_1_59) * 100000
	gen `pathogen'_sev_hiv_irate = (`pathogen'_cases_sev_hiv / pop_1_59) * 100000
	gen `pathogen'_sev_hiv_irate_lb = (`pathogen'_cases_sev_hiv_lb / pop_1_59) * 100000
	gen `pathogen'_sev_hiv_irate_ub = (`pathogen'_cases_sev_hiv_ub / pop_1_59) * 100000
	gen `pathogen'_sev_total_irate = (`pathogen'_cases_sev_total / pop_1_59) * 100000
	gen `pathogen'_sev_total_irate_lb = (`pathogen'_cases_sev_total_lb / pop_1_59) * 100000
	gen `pathogen'_sev_total_irate_ub = (`pathogen'_cases_sev_total_ub / pop_1_59) * 100000
	
	gen `pathogen'_irate = (`pathogen'_cases / pop_1_59) * 100000
	gen `pathogen'_irate_lb = (`pathogen'_cases_lb / pop_1_59) * 100000
	gen `pathogen'_irate_ub = (`pathogen'_cases_ub / pop_1_59) * 100000
	gen `pathogen'_hiv_irate = (`pathogen'_cases_hiv / pop_1_59) * 100000
	gen `pathogen'_hiv_irate_lb = (`pathogen'_cases_hiv_lb / pop_1_59) * 100000
	gen `pathogen'_hiv_irate_ub = (`pathogen'_cases_hiv_ub / pop_1_59) * 100000
	gen `pathogen'_total_irate = (`pathogen'_cases_total / pop_1_59) * 100000
	gen `pathogen'_total_irate_lb = (`pathogen'_cases_total_lb / pop_1_59) * 100000
	gen `pathogen'_total_irate_ub = (`pathogen'_cases_total_ub / pop_1_59) * 100000
}
*

* Syndrome-specific incidence rates
foreach syndrome in pneumonia meningitis npnm {
	foreach effect in "" "_d" "_n" {
		gen hib_`syndrome'_irate`effect' = (hib_`syndrome'_cases`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_irate_lb`effect' = (hib_`syndrome'_cases_lb`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_irate_ub`effect' = (hib_`syndrome'_cases_ub`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_hiv_irate`effect' = (hib_`syndrome'_cases_hiv`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_hiv_irate_lb`effect' = (hib_`syndrome'_cases_hiv_lb`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_hiv_irate_ub`effect' = (hib_`syndrome'_cases_hiv_ub`effect' / pop_1_59) * 10000
		gen hib_`syndrome'_total_irate`effect' = (hib_`syndrome'_cases_total`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_total_irate_lb`effect' = (hib_`syndrome'_cases_total_lb`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_total_irate_ub`effect' = (hib_`syndrome'_cases_total_ub`effect' / pop_1_59) * 100000
	}
}
*

foreach syndrome in pneumonia {
	foreach effect in "" {
		gen hib_`syndrome'_sev_irate`effect' = (hib_`syndrome'_cases_sev`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_irate_lb`effect' = (hib_`syndrome'_cases_sev_lb`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_irate_ub`effect' = (hib_`syndrome'_cases_sev_ub`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_hiv_irate`effect' = (hib_`syndrome'_cases_sev_hiv`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_hiv_irate_lb`effect' = (hib_`syndrome'_cases_sev_hiv_lb`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_hiv_irate_ub`effect' = (hib_`syndrome'_cases_sev_hiv_ub`effect' / pop_1_59) * 10000
		gen hib_`syndrome'_sev_total_irate`effect' = (hib_`syndrome'_cases_sev_total`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_total_irate_lb`effect' = (hib_`syndrome'_cases_sev_total_lb`effect' / pop_1_59) * 100000
		gen hib_`syndrome'_sev_total_irate_ub`effect' = (hib_`syndrome'_cases_sev_total_ub`effect' / pop_1_59) * 100000
	}
}
*

gen hib_pneumonia_sev_irate_n = (hib_pneumonia_cases_sev_n / pop_1_59) * 100000
gen hib_pneumonia_sev_irate_lb_n = (hib_pneumonia_cases_sev_lb_n / pop_1_59) * 100000
gen hib_pneumonia_sev_irate_ub_n = (hib_pneumonia_cases_sev_ub_n / pop_1_59) * 100000
gen hib_pneumonia_sev_hiv_irate_n = (hib_pneumonia_cases_sev_hiv_n / pop_1_59) * 100000
gen hib_pneumonia_sev_hiv_irate_lb_n = (hib_pneumonia_cases_sev_hiv_lb_n / pop_1_59) * 100000
gen hib_pneumonia_sev_hiv_irate_ub_n = (hib_pneumonia_cases_sev_hiv_ub_n / pop_1_59) * 100000

gen hib_pneumonia_sev_irate_d = (hib_pneumonia_cases_sev_d / pop_1_59) * 100000
gen hib_pneumonia_sev_irate_lb_d = (hib_pneumonia_cases_sev_lb_d / pop_1_59) * 100000
gen hib_pneumonia_sev_irate_ub_d = (hib_pneumonia_cases_sev_ub_d / pop_1_59) * 100000
gen hib_pneumonia_sev_hiv_irate_d = (hib_pneumonia_cases_sev_hiv_d / pop_1_59) * 100000
gen hib_pneumonia_sev_hiv_irate_lb_d = (hib_pneumonia_cases_sev_hiv_lb_d / pop_1_59) * 100000
gen hib_pneumonia_sev_hiv_irate_ub_d = (hib_pneumonia_cases_sev_hiv_ub_d / pop_1_59) * 100000




foreach syndrome in pneumonia meningitis {
	foreach effect in "" "_d" "_n" {
		gen spn_`syndrome'_irate`effect' = (spn_`syndrome'_cases`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_irate_lb`effect' = (spn_`syndrome'_cases_lb`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_irate_ub`effect' = (spn_`syndrome'_cases_ub`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_hiv_irate`effect' = (spn_`syndrome'_cases_hiv`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_hiv_irate_lb`effect' = (spn_`syndrome'_cases_hiv_lb`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_hiv_irate_ub`effect' = (spn_`syndrome'_cases_hiv_ub`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_total_irate`effect' = (spn_`syndrome'_cases_total`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_total_irate_lb`effect' = (spn_`syndrome'_cases_total_lb`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_total_irate_ub`effect' = (spn_`syndrome'_cases_total_ub`effect' / pop_1_59) * 100000
	}
}
*


foreach syndrome in pneumonia   {
	foreach effect in "" {
		gen spn_`syndrome'_sev_irate`effect' = (spn_`syndrome'_cases_sev`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_irate_lb`effect' = (spn_`syndrome'_cases_sev_lb`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_irate_ub`effect' = (spn_`syndrome'_cases_sev_ub`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_hiv_irate`effect' = (spn_`syndrome'_cases_sev_hiv`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_hiv_irate_lb`effect' = (spn_`syndrome'_cases_sev_hiv_lb`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_hiv_irate_ub`effect' = (spn_`syndrome'_cases_sev_hiv_ub`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_total_irate`effect' = (spn_`syndrome'_cases_sev_total`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_total_irate_lb`effect' = (spn_`syndrome'_cases_sev_total_lb`effect' / pop_1_59) * 100000
		gen spn_`syndrome'_sev_total_irate_ub`effect' = (spn_`syndrome'_cases_sev_total_ub`effect' / pop_1_59) * 100000
	}
}
*
gen spn_pneumonia_sev_irate_n = (spn_pneumonia_cases_sev_n / pop_1_59) * 100000
gen spn_pneumonia_sev_irate_lb_n = (spn_pneumonia_cases_sev_lb_n / pop_1_59) * 100000
gen spn_pneumonia_sev_irate_ub_n = (spn_pneumonia_cases_sev_ub_n / pop_1_59) * 100000
gen spn_pneumonia_sev_hiv_irate_n = (spn_pneumonia_cases_sev_hiv_n / pop_1_59) * 100000
gen spn_pneumonia_sev_hiv_irate_lb_n = (spn_pneumonia_cases_sev_hiv_lb_n / pop_1_59) * 100000
gen spn_pneumonia_sev_hiv_irate_ub_n = (spn_pneumonia_cases_sev_hiv_ub_n / pop_1_59) * 100000

gen spn_pneumonia_sev_irate_d = (spn_pneumonia_cases_sev_d / pop_1_59) * 100000
gen spn_pneumonia_sev_irate_lb_d = (spn_pneumonia_cases_sev_lb_d / pop_1_59) * 100000
gen spn_pneumonia_sev_irate_ub_d = (spn_pneumonia_cases_sev_ub_d / pop_1_59) * 100000
gen spn_pneumonia_sev_hiv_irate_d = (spn_pneumonia_cases_sev_hiv_d / pop_1_59) * 100000
gen spn_pneumonia_sev_hiv_irate_lb_d = (spn_pneumonia_cases_sev_hiv_lb_d / pop_1_59) * 100000
gen spn_pneumonia_sev_hiv_irate_ub_d = (spn_pneumonia_cases_sev_hiv_ub_d / pop_1_59) * 100000



* Severe
foreach effect in "" "_d" "_n" {
	gen spn_npnm_irate`effect' = (spn_npnm_cases`effect' / pop_1_59) * 100000
	gen spn_npnm_irate_lb`effect' = (spn_npnm_cases_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_irate_ub`effect' = (spn_npnm_cases_ub`effect' / pop_1_59) * 100000
	gen spn_npnm_hiv_irate`effect' = (spn_npnm_cases_hiv`effect' / pop_1_59) * 100000
	gen spn_npnm_hiv_irate_lb`effect' = (spn_npnm_cases_hiv_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_hiv_irate_ub`effect' = (spn_npnm_cases_hiv_ub`effect' / pop_1_59) * 100000
	gen spn_npnm_total_irate`effect' = (spn_npnm_cases_total`effect' / pop_1_59) * 100000
	gen spn_npnm_total_irate_lb`effect' = (spn_npnm_cases_total_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_total_irate_ub`effect' = (spn_npnm_cases_total_ub`effect' / pop_1_59) * 100000
}
* Non-severe
foreach effect in "" "_d" "_n" {		
	gen spn_npnm_nonsev_irate`effect' = (spn_npnm_cases_nonsev`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_irate_lb`effect' = (spn_npnm_cases_nonsev_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_irate_ub`effect' = (spn_npnm_cases_nonsev_ub`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_hiv_irate`effect' = (spn_npnm_cases_nonsev_hiv`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_hiv_irate_lb`effect' = (spn_npnm_cases_nonsev_hiv_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_hiv_irate_ub`effect' = (spn_npnm_cases_nonsev_hiv_ub`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_total_irate`effect' = (spn_npnm_cases_nonsev_total`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_total_irate_lb`effect' = (spn_npnm_cases_nonsev_total_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_nonsev_total_irate_ub`effect' = (spn_npnm_cases_nonsev_total_ub`effect' / pop_1_59) * 100000
}
*

* Total (severe and non-severe) 
foreach effect in "" "_d" "_n" {		
	gen spn_npnm_cases_sevnon`effect' = spn_npnm_cases`effect' + spn_npnm_cases_nonsev`effect'
	gen spn_npnm_cases_sevnon_lb`effect' = spn_npnm_cases_lb`effect' + spn_npnm_cases_nonsev_lb`effect'
	gen spn_npnm_cases_sevnon_ub`effect' = spn_npnm_cases_ub`effect' + spn_npnm_cases_nonsev_ub`effect'
	gen spn_npnm_cases_sevnon_hiv`effect' = spn_npnm_cases_hiv`effect' + spn_npnm_cases_nonsev_hiv`effect'
	gen spn_npnm_cases_sevnon_hiv_lb`effect' = spn_npnm_cases_hiv_lb`effect' + spn_npnm_cases_nonsev_hiv_lb`effect'
	gen spn_npnm_cases_sevnon_hiv_ub`effect' = spn_npnm_cases_hiv_ub`effect' + spn_npnm_cases_nonsev_hiv_ub`effect'
	gen spn_npnm_cases_sevnon_total`effect' = spn_npnm_cases_total`effect' + spn_npnm_cases_nonsev_total`effect'
	gen spn_npnm_cases_sevnon_total_lb`effect' = spn_npnm_cases_total_lb`effect' + spn_npnm_cases_nonsev_total_lb`effect'
	gen spn_npnm_cases_sevnon_total_ub`effect' = spn_npnm_cases_total_ub`effect' + spn_npnm_cases_nonsev_total_ub`effect'
}

foreach effect in "" "_d" "_n" {		
	gen spn_npnm_sevnon_irate`effect' = (spn_npnm_cases_sevnon`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_irate_lb`effect' = (spn_npnm_cases_sevnon_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_irate_ub`effect' = (spn_npnm_cases_sevnon_ub`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_hiv_irate`effect' = (spn_npnm_cases_sevnon_hiv`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_hiv_irate_lb`effect' = (spn_npnm_cases_sevnon_hiv_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_hiv_irate_ub`effect' = (spn_npnm_cases_sevnon_hiv_ub`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_total_irate`effect' = (spn_npnm_cases_sevnon_total`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_total_irate_lb`effect' = (spn_npnm_cases_sevnon_total_lb`effect' / pop_1_59) * 100000
	gen spn_npnm_sevnon_total_irate_ub`effect' = (spn_npnm_cases_sevnon_total_ub`effect' / pop_1_59) * 100000
}
*

* NM meningitis incidence rates
foreach effect in "" "_n" {
	gen nm_meningitis_irate`effect' = (nm_meningitis_cases`effect' / pop_1_59) * 100000
	gen nm_meningitis_irate_lb`effect' = (nm_meningitis_cases_lb`effect' / pop_1_59) * 100000	
	gen nm_meningitis_irate_ub`effect' = (nm_meningitis_cases_ub`effect' / pop_1_59) * 100000
	gen nm_meningitis_hiv_irate`effect' = (nm_meningitis_cases_hiv`effect' / pop_1_59) * 100000
	gen nm_meningitis_hiv_irate_lb`effect' = (nm_meningitis_cases_hiv_lb`effect' / pop_1_59) * 100000
	gen nm_meningitis_hiv_irate_ub`effect' = (nm_meningitis_cases_hiv_ub`effect' / pop_1_59) * 100000
	gen nm_meningitis_total_irate`effect' = (nm_meningitis_cases_total`effect' / pop_1_59) * 100000
	gen nm_meningitis_total_irate_lb`effect' = (nm_meningitis_cases_total_lb`effect' / pop_1_59) * 100000
	gen nm_meningitis_total_irate_ub`effect' = (nm_meningitis_cases_total_ub`effect' / pop_1_59) * 100000
}
*

* CFR estimates (HIV-)
foreach effect in "" "_n" {
	foreach pathogen in spn hib {
		foreach syndrome in pneumonia meningitis npnm {
			gen `pathogen'_`syndrome'_cfr`effect' = `pathogen'_`syndrome'_deaths`effect' / `pathogen'_`syndrome'_cases`effect' 
			gen `pathogen'_`syndrome'_cfr_lb`effect' = `pathogen'_`syndrome'_deaths_lb`effect' / `pathogen'_`syndrome'_cases`effect' 
			gen `pathogen'_`syndrome'_cfr_ub`effect' = `pathogen'_`syndrome'_deaths_ub`effect' / `pathogen'_`syndrome'_cases`effect' 
			replace `pathogen'_`syndrome'_cfr_ub`effect' = 1 if `pathogen'_`syndrome'_cfr_ub`effect' > 1 & `pathogen'_`syndrome'_cfr_ub`effect'  != .
		}
	}
}
*

foreach effect in "" "_n" {
	foreach pathogen in spn hib {
		gen `pathogen'_pneumonia_sev_cfr`effect' = `pathogen'_pneumonia_deaths`effect' / `pathogen'_pneumonia_cases_sev`effect' 
		gen `pathogen'_pneumonia_sev_cfr_lb`effect' = `pathogen'_pneumonia_deaths_lb`effect' / `pathogen'_pneumonia_cases_sev`effect' 
		gen `pathogen'_pneumonia_sev_cfr_ub`effect' = `pathogen'_pneumonia_deaths_ub`effect' / `pathogen'_pneumonia_cases_sev`effect' 
		replace `pathogen'_pneumonia_sev_cfr_ub`effect' = 1 if `pathogen'_pneumonia_sev_cfr_ub`effect' > 1 & `pathogen'_pneumonia_sev_cfr_ub`effect'  != .
	}
}
*


* CFR estimates (HIV+)
foreach effect in "" "_n" {
	foreach pathogen in spn hib {
		foreach syndrome in pneumonia meningitis npnm {
			gen `pathogen'_`syndrome'_cfr_hiv`effect' = `pathogen'_`syndrome'_deaths_hiv`effect' / `pathogen'_`syndrome'_cases_hiv`effect' 
			gen `pathogen'_`syndrome'_cfr_hiv_lb`effect' = `pathogen'_`syndrome'_deaths_hiv_lb`effect' / `pathogen'_`syndrome'_cases_hiv`effect' 
			gen `pathogen'_`syndrome'_cfr_hiv_ub`effect' = `pathogen'_`syndrome'_deaths_hiv_ub`effect' / `pathogen'_`syndrome'_cases_hiv`effect' 
			replace `pathogen'_`syndrome'_cfr_hiv_ub`effect' = 1 if `pathogen'_`syndrome'_cfr_hiv_ub`effect' > 1 & `pathogen'_`syndrome'_cfr_hiv_ub`effect' != .
		}
	}
}
*

foreach effect in "" "_n" {
	foreach pathogen in spn hib {
		gen `pathogen'_pneumonia_sev_cfr_hiv`effect' = `pathogen'_pneumonia_deaths_hiv`effect' / `pathogen'_pneumonia_cases_sev_hiv`effect' 
		gen `pathogen'_pneumonia_sev_cfr_hiv_lb`effect' = `pathogen'_pneumonia_deaths_hiv_lb`effect' / `pathogen'_pneumonia_cases_sev_hiv`effect'  
		gen `pathogen'_pneumonia_sev_cfr_hiv_ub`effect' = `pathogen'_pneumonia_deaths_hiv_ub`effect' / `pathogen'_pneumonia_cases_sev_hiv`effect' 
		replace `pathogen'_pneumonia_sev_cfr_hiv_ub`effect' = 1 if `pathogen'_pneumonia_sev_cfr_hiv_ub`effect' > 1 & `pathogen'_pneumonia_sev_cfr_hiv_ub`effect'  != .
	}
}
*



* CFR estimates (Both HIV- & HIV+)
foreach effect in "" "_n" {
	foreach pathogen in spn hib {
		foreach syndrome in pneumonia meningitis npnm {
			gen `pathogen'_`syndrome'_cfr_total`effect' = `pathogen'_`syndrome'_deaths_total`effect' / `pathogen'_`syndrome'_cases_total`effect' 
			gen `pathogen'_`syndrome'_cfr_total_lb`effect' = `pathogen'_`syndrome'_deaths_total_lb`effect' / `pathogen'_`syndrome'_cases_total`effect' 
			gen `pathogen'_`syndrome'_cfr_total_ub`effect' = `pathogen'_`syndrome'_deaths_total_ub`effect' / `pathogen'_`syndrome'_cases_total`effect' 
			replace `pathogen'_`syndrome'_cfr_total_ub`effect' = 1 if `pathogen'_`syndrome'_cfr_total_ub`effect' > 1 & `pathogen'_`syndrome'_cfr_total_ub`effect' != .
		}
	}
}
*

* Severe pneumonia
foreach effect in "" "_n" {
	foreach pathogen in spn hib {
		gen `pathogen'_pneumonia_sev_cfr_total`effect' = `pathogen'_pneumonia_deaths_total`effect' / `pathogen'_pneumonia_cases_sev_total`effect' 
		gen `pathogen'_pneumonia_sev_cfr_total_lb`effect' = `pathogen'_pneumonia_deaths_total_lb`effect' / `pathogen'_pneumonia_cases_sev_total`effect' 
		gen `pathogen'_pneumonia_sev_cfr_total_ub`effect' = `pathogen'_pneumonia_deaths_total_ub`effect' / `pathogen'_pneumonia_cases_sev_total`effect' 
		replace `pathogen'_pneumonia_sev_cfr_total_ub`effect' = 1 if `pathogen'_pneumonia_sev_cfr_total_ub`effect' > 1 & `pathogen'_pneumonia_sev_cfr_total_ub`effect' != .
	}
}
*




save "countries_time_series_results.dta", replace

* END OF .DO FILE

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************











